'''OpenGL extension NV.vertex_program

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_vertex_program'
_DEPRECATED = False
GL_VERTEX_PROGRAM_NV = constant.Constant( 'GL_VERTEX_PROGRAM_NV', 0x8620 )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_NV, (1,) )
GL_VERTEX_STATE_PROGRAM_NV = constant.Constant( 'GL_VERTEX_STATE_PROGRAM_NV', 0x8621 )
GL_ATTRIB_ARRAY_SIZE_NV = constant.Constant( 'GL_ATTRIB_ARRAY_SIZE_NV', 0x8623 )
GL_ATTRIB_ARRAY_STRIDE_NV = constant.Constant( 'GL_ATTRIB_ARRAY_STRIDE_NV', 0x8624 )
GL_ATTRIB_ARRAY_TYPE_NV = constant.Constant( 'GL_ATTRIB_ARRAY_TYPE_NV', 0x8625 )
GL_CURRENT_ATTRIB_NV = constant.Constant( 'GL_CURRENT_ATTRIB_NV', 0x8626 )
GL_PROGRAM_LENGTH_NV = constant.Constant( 'GL_PROGRAM_LENGTH_NV', 0x8627 )
GL_PROGRAM_STRING_NV = constant.Constant( 'GL_PROGRAM_STRING_NV', 0x8628 )
GL_MODELVIEW_PROJECTION_NV = constant.Constant( 'GL_MODELVIEW_PROJECTION_NV', 0x8629 )
GL_IDENTITY_NV = constant.Constant( 'GL_IDENTITY_NV', 0x862A )
GL_INVERSE_NV = constant.Constant( 'GL_INVERSE_NV', 0x862B )
GL_TRANSPOSE_NV = constant.Constant( 'GL_TRANSPOSE_NV', 0x862C )
GL_INVERSE_TRANSPOSE_NV = constant.Constant( 'GL_INVERSE_TRANSPOSE_NV', 0x862D )
GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV = constant.Constant( 'GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV', 0x862E )
glget.addGLGetConstant( GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV, (1,) )
GL_MAX_TRACK_MATRICES_NV = constant.Constant( 'GL_MAX_TRACK_MATRICES_NV', 0x862F )
glget.addGLGetConstant( GL_MAX_TRACK_MATRICES_NV, (1,) )
GL_MATRIX0_NV = constant.Constant( 'GL_MATRIX0_NV', 0x8630 )
GL_MATRIX1_NV = constant.Constant( 'GL_MATRIX1_NV', 0x8631 )
GL_MATRIX2_NV = constant.Constant( 'GL_MATRIX2_NV', 0x8632 )
GL_MATRIX3_NV = constant.Constant( 'GL_MATRIX3_NV', 0x8633 )
GL_MATRIX4_NV = constant.Constant( 'GL_MATRIX4_NV', 0x8634 )
GL_MATRIX5_NV = constant.Constant( 'GL_MATRIX5_NV', 0x8635 )
GL_MATRIX6_NV = constant.Constant( 'GL_MATRIX6_NV', 0x8636 )
GL_MATRIX7_NV = constant.Constant( 'GL_MATRIX7_NV', 0x8637 )
GL_CURRENT_MATRIX_STACK_DEPTH_NV = constant.Constant( 'GL_CURRENT_MATRIX_STACK_DEPTH_NV', 0x8640 )
glget.addGLGetConstant( GL_CURRENT_MATRIX_STACK_DEPTH_NV, (1,) )
GL_CURRENT_MATRIX_NV = constant.Constant( 'GL_CURRENT_MATRIX_NV', 0x8641 )
glget.addGLGetConstant( GL_CURRENT_MATRIX_NV, (4,4) )
GL_VERTEX_PROGRAM_POINT_SIZE_NV = constant.Constant( 'GL_VERTEX_PROGRAM_POINT_SIZE_NV', 0x8642 )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_POINT_SIZE_NV, (1,) )
GL_VERTEX_PROGRAM_TWO_SIDE_NV = constant.Constant( 'GL_VERTEX_PROGRAM_TWO_SIDE_NV', 0x8643 )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_TWO_SIDE_NV, (1,) )
GL_PROGRAM_PARAMETER_NV = constant.Constant( 'GL_PROGRAM_PARAMETER_NV', 0x8644 )
GL_ATTRIB_ARRAY_POINTER_NV = constant.Constant( 'GL_ATTRIB_ARRAY_POINTER_NV', 0x8645 )
GL_PROGRAM_TARGET_NV = constant.Constant( 'GL_PROGRAM_TARGET_NV', 0x8646 )
GL_PROGRAM_RESIDENT_NV = constant.Constant( 'GL_PROGRAM_RESIDENT_NV', 0x8647 )
GL_TRACK_MATRIX_NV = constant.Constant( 'GL_TRACK_MATRIX_NV', 0x8648 )
GL_TRACK_MATRIX_TRANSFORM_NV = constant.Constant( 'GL_TRACK_MATRIX_TRANSFORM_NV', 0x8649 )
GL_VERTEX_PROGRAM_BINDING_NV = constant.Constant( 'GL_VERTEX_PROGRAM_BINDING_NV', 0x864A )
glget.addGLGetConstant( GL_VERTEX_PROGRAM_BINDING_NV, (1,) )
GL_PROGRAM_ERROR_POSITION_NV = constant.Constant( 'GL_PROGRAM_ERROR_POSITION_NV', 0x864B )
glget.addGLGetConstant( GL_PROGRAM_ERROR_POSITION_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY0_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY0_NV', 0x8650 )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY0_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY1_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY1_NV', 0x8651 )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY1_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY2_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY2_NV', 0x8652 )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY2_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY3_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY3_NV', 0x8653 )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY3_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY4_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY4_NV', 0x8654 )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY4_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY5_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY5_NV', 0x8655 )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY5_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY6_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY6_NV', 0x8656 )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY6_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY7_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY7_NV', 0x8657 )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY7_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY8_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY8_NV', 0x8658 )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY8_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY9_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY9_NV', 0x8659 )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY9_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY10_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY10_NV', 0x865A )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY10_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY11_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY11_NV', 0x865B )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY11_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY12_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY12_NV', 0x865C )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY12_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY13_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY13_NV', 0x865D )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY13_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY14_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY14_NV', 0x865E )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY14_NV, (1,) )
GL_VERTEX_ATTRIB_ARRAY15_NV = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY15_NV', 0x865F )
glget.addGLGetConstant( GL_VERTEX_ATTRIB_ARRAY15_NV, (1,) )
GL_MAP1_VERTEX_ATTRIB0_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB0_4_NV', 0x8660 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB0_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB1_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB1_4_NV', 0x8661 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB1_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB2_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB2_4_NV', 0x8662 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB2_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB3_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB3_4_NV', 0x8663 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB3_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB4_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB4_4_NV', 0x8664 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB4_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB5_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB5_4_NV', 0x8665 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB5_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB6_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB6_4_NV', 0x8666 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB6_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB7_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB7_4_NV', 0x8667 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB7_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB8_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB8_4_NV', 0x8668 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB8_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB9_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB9_4_NV', 0x8669 )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB9_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB10_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB10_4_NV', 0x866A )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB10_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB11_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB11_4_NV', 0x866B )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB11_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB12_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB12_4_NV', 0x866C )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB12_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB13_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB13_4_NV', 0x866D )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB13_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB14_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB14_4_NV', 0x866E )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB14_4_NV, (4,) )
GL_MAP1_VERTEX_ATTRIB15_4_NV = constant.Constant( 'GL_MAP1_VERTEX_ATTRIB15_4_NV', 0x866F )
glget.addGLGetConstant( GL_MAP1_VERTEX_ATTRIB15_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB0_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB0_4_NV', 0x8670 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB0_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB1_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB1_4_NV', 0x8671 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB1_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB2_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB2_4_NV', 0x8672 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB2_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB3_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB3_4_NV', 0x8673 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB3_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB4_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB4_4_NV', 0x8674 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB4_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB5_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB5_4_NV', 0x8675 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB5_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB6_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB6_4_NV', 0x8676 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB6_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB7_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB7_4_NV', 0x8677 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB7_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB8_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB8_4_NV', 0x8678 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB8_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB9_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB9_4_NV', 0x8679 )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB9_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB10_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB10_4_NV', 0x867A )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB10_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB11_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB11_4_NV', 0x867B )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB11_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB12_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB12_4_NV', 0x867C )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB12_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB13_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB13_4_NV', 0x867D )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB13_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB14_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB14_4_NV', 0x867E )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB14_4_NV, (4,) )
GL_MAP2_VERTEX_ATTRIB15_4_NV = constant.Constant( 'GL_MAP2_VERTEX_ATTRIB15_4_NV', 0x867F )
glget.addGLGetConstant( GL_MAP2_VERTEX_ATTRIB15_4_NV, (4,) )
glAreProgramsResidentNV = platform.createExtensionFunction( 
'glAreProgramsResidentNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLsizei,arrays.GLuintArray,arrays.GLbooleanArray,),
doc='glAreProgramsResidentNV(GLsizei(n), GLuintArray(programs), GLbooleanArray(residences)) -> constants.GLboolean',
argNames=('n','programs','residences',),
deprecated=_DEPRECATED,
)

glBindProgramNV = platform.createExtensionFunction( 
'glBindProgramNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glBindProgramNV(GLenum(target), GLuint(id)) -> None',
argNames=('target','id',),
deprecated=_DEPRECATED,
)

glDeleteProgramsNV = platform.createExtensionFunction( 
'glDeleteProgramsNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteProgramsNV(GLsizei(n), GLuintArray(programs)) -> None',
argNames=('n','programs',),
deprecated=_DEPRECATED,
)

glExecuteProgramNV = platform.createExtensionFunction( 
'glExecuteProgramNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLfloatArray,),
doc='glExecuteProgramNV(GLenum(target), GLuint(id), GLfloatArray(params)) -> None',
argNames=('target','id','params',),
deprecated=_DEPRECATED,
)

glGenProgramsNV = platform.createExtensionFunction( 
'glGenProgramsNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenProgramsNV(GLsizei(n), GLuintArray(programs)) -> None',
argNames=('n','programs',),
deprecated=_DEPRECATED,
)

glGetProgramParameterdvNV = platform.createExtensionFunction( 
'glGetProgramParameterdvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLenum,arrays.GLdoubleArray,),
doc='glGetProgramParameterdvNV(GLenum(target), GLuint(index), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('target','index','pname','params',),
deprecated=_DEPRECATED,
)

glGetProgramParameterfvNV = platform.createExtensionFunction( 
'glGetProgramParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetProgramParameterfvNV(GLenum(target), GLuint(index), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','index','pname','params',),
deprecated=_DEPRECATED,
)

glGetProgramivNV = platform.createExtensionFunction( 
'glGetProgramivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetProgramivNV(GLuint(id), GLenum(pname), GLintArray(params)) -> None',
argNames=('id','pname','params',),
deprecated=_DEPRECATED,
)

glGetProgramStringNV = platform.createExtensionFunction( 
'glGetProgramStringNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLubyteArray,),
doc='glGetProgramStringNV(GLuint(id), GLenum(pname), GLubyteArray(program)) -> None',
argNames=('id','pname','program',),
deprecated=_DEPRECATED,
)

glGetTrackMatrixivNV = platform.createExtensionFunction( 
'glGetTrackMatrixivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetTrackMatrixivNV(GLenum(target), GLuint(address), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','address','pname','params',),
deprecated=_DEPRECATED,
)

glGetVertexAttribdvNV = platform.createExtensionFunction( 
'glGetVertexAttribdvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLdoubleArray,),
doc='glGetVertexAttribdvNV(GLuint(index), GLenum(pname), GLdoubleArray(params)) -> None',
argNames=('index','pname','params',),
deprecated=_DEPRECATED,
)

glGetVertexAttribfvNV = platform.createExtensionFunction( 
'glGetVertexAttribfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetVertexAttribfvNV(GLuint(index), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('index','pname','params',),
deprecated=_DEPRECATED,
)

glGetVertexAttribivNV = platform.createExtensionFunction( 
'glGetVertexAttribivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetVertexAttribivNV(GLuint(index), GLenum(pname), GLintArray(params)) -> None',
argNames=('index','pname','params',),
deprecated=_DEPRECATED,
)

glGetVertexAttribPointervNV = platform.createExtensionFunction( 
'glGetVertexAttribPointervNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,ctypes.POINTER(ctypes.c_void_p),),
doc='glGetVertexAttribPointervNV(GLuint(index), GLenum(pname), POINTER(ctypes.c_void_p)(pointer)) -> None',
argNames=('index','pname','pointer',),
deprecated=_DEPRECATED,
)

glIsProgramNV = platform.createExtensionFunction( 
'glIsProgramNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsProgramNV(GLuint(id)) -> constants.GLboolean',
argNames=('id',),
deprecated=_DEPRECATED,
)

glLoadProgramNV = platform.createExtensionFunction( 
'glLoadProgramNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLubyteArray,),
doc='glLoadProgramNV(GLenum(target), GLuint(id), GLsizei(len), GLubyteArray(program)) -> None',
argNames=('target','id','len','program',),
deprecated=_DEPRECATED,
)

glProgramParameter4dNV = platform.createExtensionFunction( 
'glProgramParameter4dNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glProgramParameter4dNV(GLenum(target), GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w)) -> None',
argNames=('target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramParameter4dvNV = platform.createExtensionFunction( 
'glProgramParameter4dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLdoubleArray,),
doc='glProgramParameter4dvNV(GLenum(target), GLuint(index), GLdoubleArray(v)) -> None',
argNames=('target','index','v',),
deprecated=_DEPRECATED,
)

glProgramParameter4fNV = platform.createExtensionFunction( 
'glProgramParameter4fNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glProgramParameter4fNV(GLenum(target), GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w)) -> None',
argNames=('target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramParameter4fvNV = platform.createExtensionFunction( 
'glProgramParameter4fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLfloatArray,),
doc='glProgramParameter4fvNV(GLenum(target), GLuint(index), GLfloatArray(v)) -> None',
argNames=('target','index','v',),
deprecated=_DEPRECATED,
)

glProgramParameters4dvNV = platform.createExtensionFunction( 
'glProgramParameters4dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,arrays.GLdoubleArray,),
doc='glProgramParameters4dvNV(GLenum(target), GLuint(index), GLuint(count), GLdoubleArray(v)) -> None',
argNames=('target','index','count','v',),
deprecated=_DEPRECATED,
)

glProgramParameters4fvNV = platform.createExtensionFunction( 
'glProgramParameters4fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,arrays.GLfloatArray,),
doc='glProgramParameters4fvNV(GLenum(target), GLuint(index), GLuint(count), GLfloatArray(v)) -> None',
argNames=('target','index','count','v',),
deprecated=_DEPRECATED,
)

glRequestResidentProgramsNV = platform.createExtensionFunction( 
'glRequestResidentProgramsNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glRequestResidentProgramsNV(GLsizei(n), GLuintArray(programs)) -> None',
argNames=('n','programs',),
deprecated=_DEPRECATED,
)

glTrackMatrixNV = platform.createExtensionFunction( 
'glTrackMatrixNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLenum,constants.GLenum,),
doc='glTrackMatrixNV(GLenum(target), GLuint(address), GLenum(matrix), GLenum(transform)) -> None',
argNames=('target','address','matrix','transform',),
deprecated=_DEPRECATED,
)

glVertexAttribPointerNV = platform.createExtensionFunction( 
'glVertexAttribPointerNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glVertexAttribPointerNV(GLuint(index), GLint(fsize), GLenum(type), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('index','fsize','type','stride','pointer',),
deprecated=_DEPRECATED,
)

glVertexAttrib1dNV = platform.createExtensionFunction( 
'glVertexAttrib1dNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLdouble,),
doc='glVertexAttrib1dNV(GLuint(index), GLdouble(x)) -> None',
argNames=('index','x',),
deprecated=_DEPRECATED,
)

glVertexAttrib1dvNV = platform.createExtensionFunction( 
'glVertexAttrib1dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLdoubleArray,),
doc='glVertexAttrib1dvNV(GLuint(index), GLdoubleArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib1fNV = platform.createExtensionFunction( 
'glVertexAttrib1fNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,),
doc='glVertexAttrib1fNV(GLuint(index), GLfloat(x)) -> None',
argNames=('index','x',),
deprecated=_DEPRECATED,
)

glVertexAttrib1fvNV = platform.createExtensionFunction( 
'glVertexAttrib1fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLfloatArray,),
doc='glVertexAttrib1fvNV(GLuint(index), GLfloatArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib1sNV = platform.createExtensionFunction( 
'glVertexAttrib1sNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLshort,),
doc='glVertexAttrib1sNV(GLuint(index), GLshort(x)) -> None',
argNames=('index','x',),
deprecated=_DEPRECATED,
)

glVertexAttrib1svNV = platform.createExtensionFunction( 
'glVertexAttrib1svNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVertexAttrib1svNV(GLuint(index), GLshortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib2dNV = platform.createExtensionFunction( 
'glVertexAttrib2dNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLdouble,constants.GLdouble,),
doc='glVertexAttrib2dNV(GLuint(index), GLdouble(x), GLdouble(y)) -> None',
argNames=('index','x','y',),
deprecated=_DEPRECATED,
)

glVertexAttrib2dvNV = platform.createExtensionFunction( 
'glVertexAttrib2dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLdoubleArray,),
doc='glVertexAttrib2dvNV(GLuint(index), GLdoubleArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib2fNV = platform.createExtensionFunction( 
'glVertexAttrib2fNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,),
doc='glVertexAttrib2fNV(GLuint(index), GLfloat(x), GLfloat(y)) -> None',
argNames=('index','x','y',),
deprecated=_DEPRECATED,
)

glVertexAttrib2fvNV = platform.createExtensionFunction( 
'glVertexAttrib2fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLfloatArray,),
doc='glVertexAttrib2fvNV(GLuint(index), GLfloatArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib2sNV = platform.createExtensionFunction( 
'glVertexAttrib2sNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLshort,constants.GLshort,),
doc='glVertexAttrib2sNV(GLuint(index), GLshort(x), GLshort(y)) -> None',
argNames=('index','x','y',),
deprecated=_DEPRECATED,
)

glVertexAttrib2svNV = platform.createExtensionFunction( 
'glVertexAttrib2svNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVertexAttrib2svNV(GLuint(index), GLshortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib3dNV = platform.createExtensionFunction( 
'glVertexAttrib3dNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glVertexAttrib3dNV(GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z)) -> None',
argNames=('index','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexAttrib3dvNV = platform.createExtensionFunction( 
'glVertexAttrib3dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLdoubleArray,),
doc='glVertexAttrib3dvNV(GLuint(index), GLdoubleArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib3fNV = platform.createExtensionFunction( 
'glVertexAttrib3fNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glVertexAttrib3fNV(GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z)) -> None',
argNames=('index','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexAttrib3fvNV = platform.createExtensionFunction( 
'glVertexAttrib3fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLfloatArray,),
doc='glVertexAttrib3fvNV(GLuint(index), GLfloatArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib3sNV = platform.createExtensionFunction( 
'glVertexAttrib3sNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glVertexAttrib3sNV(GLuint(index), GLshort(x), GLshort(y), GLshort(z)) -> None',
argNames=('index','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexAttrib3svNV = platform.createExtensionFunction( 
'glVertexAttrib3svNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVertexAttrib3svNV(GLuint(index), GLshortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4dNV = platform.createExtensionFunction( 
'glVertexAttrib4dNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLdouble,constants.GLdouble,constants.GLdouble,constants.GLdouble,),
doc='glVertexAttrib4dNV(GLuint(index), GLdouble(x), GLdouble(y), GLdouble(z), GLdouble(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttrib4dvNV = platform.createExtensionFunction( 
'glVertexAttrib4dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLdoubleArray,),
doc='glVertexAttrib4dvNV(GLuint(index), GLdoubleArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4fNV = platform.createExtensionFunction( 
'glVertexAttrib4fNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLfloat,constants.GLfloat,constants.GLfloat,constants.GLfloat,),
doc='glVertexAttrib4fNV(GLuint(index), GLfloat(x), GLfloat(y), GLfloat(z), GLfloat(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttrib4fvNV = platform.createExtensionFunction( 
'glVertexAttrib4fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLfloatArray,),
doc='glVertexAttrib4fvNV(GLuint(index), GLfloatArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4sNV = platform.createExtensionFunction( 
'glVertexAttrib4sNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLshort,constants.GLshort,constants.GLshort,constants.GLshort,),
doc='glVertexAttrib4sNV(GLuint(index), GLshort(x), GLshort(y), GLshort(z), GLshort(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttrib4svNV = platform.createExtensionFunction( 
'glVertexAttrib4svNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVertexAttrib4svNV(GLuint(index), GLshortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4ubNV = platform.createExtensionFunction( 
'glVertexAttrib4ubNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLubyte,constants.GLubyte,constants.GLubyte,constants.GLubyte,),
doc='glVertexAttrib4ubNV(GLuint(index), GLubyte(x), GLubyte(y), GLubyte(z), GLubyte(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttrib4ubvNV = platform.createExtensionFunction( 
'glVertexAttrib4ubvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLubyteArray,),
doc='glVertexAttrib4ubvNV(GLuint(index), GLubyteArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs1dvNV = platform.createExtensionFunction( 
'glVertexAttribs1dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLdoubleArray,),
doc='glVertexAttribs1dvNV(GLuint(index), GLsizei(count), GLdoubleArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs1fvNV = platform.createExtensionFunction( 
'glVertexAttribs1fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLfloatArray,),
doc='glVertexAttribs1fvNV(GLuint(index), GLsizei(count), GLfloatArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs1svNV = platform.createExtensionFunction( 
'glVertexAttribs1svNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLshortArray,),
doc='glVertexAttribs1svNV(GLuint(index), GLsizei(count), GLshortArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs2dvNV = platform.createExtensionFunction( 
'glVertexAttribs2dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLdoubleArray,),
doc='glVertexAttribs2dvNV(GLuint(index), GLsizei(count), GLdoubleArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs2fvNV = platform.createExtensionFunction( 
'glVertexAttribs2fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLfloatArray,),
doc='glVertexAttribs2fvNV(GLuint(index), GLsizei(count), GLfloatArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs2svNV = platform.createExtensionFunction( 
'glVertexAttribs2svNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLshortArray,),
doc='glVertexAttribs2svNV(GLuint(index), GLsizei(count), GLshortArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs3dvNV = platform.createExtensionFunction( 
'glVertexAttribs3dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLdoubleArray,),
doc='glVertexAttribs3dvNV(GLuint(index), GLsizei(count), GLdoubleArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs3fvNV = platform.createExtensionFunction( 
'glVertexAttribs3fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLfloatArray,),
doc='glVertexAttribs3fvNV(GLuint(index), GLsizei(count), GLfloatArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs3svNV = platform.createExtensionFunction( 
'glVertexAttribs3svNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLshortArray,),
doc='glVertexAttribs3svNV(GLuint(index), GLsizei(count), GLshortArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs4dvNV = platform.createExtensionFunction( 
'glVertexAttribs4dvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLdoubleArray,),
doc='glVertexAttribs4dvNV(GLuint(index), GLsizei(count), GLdoubleArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs4fvNV = platform.createExtensionFunction( 
'glVertexAttribs4fvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLfloatArray,),
doc='glVertexAttribs4fvNV(GLuint(index), GLsizei(count), GLfloatArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs4svNV = platform.createExtensionFunction( 
'glVertexAttribs4svNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLshortArray,),
doc='glVertexAttribs4svNV(GLuint(index), GLsizei(count), GLshortArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs4ubvNV = platform.createExtensionFunction( 
'glVertexAttribs4ubvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLubyteArray,),
doc='glVertexAttribs4ubvNV(GLuint(index), GLsizei(count), GLubyteArray(v)) -> None',
argNames=('index','count','v',),
deprecated=_DEPRECATED,
)


def glInitVertexProgramNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



"""Implementation of the special "glGet" functions

For comparison, here's what a straightforward implementation looks like:

    def glGetDoublev( pname ):
        "Natural writing of glGetDoublev using standard ctypes"
        output = c_double*sizes.get( pname )
        result = output()
        result = platform.OpenGL.glGetDoublev( pname, byref(result) )
        return Numeric.array( result )
"""
from OpenGL import platform, arrays, error, wrapper, converters
from OpenGL.raw import GL as simple
import ctypes
GLenum = ctypes.c_uint
GLsize = GLsizei = ctypes.c_int

__all__ = (
    'glGetBoolean','glGetBooleanv','glGetInteger','glGetIntegerv',
    'glGetFloat','glGetFloatv','glGetDouble','glGetDoublev',
    'glGetString',
    'glGetLightfv','glGetLightiv',
    'glGetMaterialfv','glGetMaterialiv',
    'glGetPixelMapfv','glGetPixelMapusv','glGetPixelMapuiv',
    'glGetPolygonStipple', 'glGetPolygonStippleub',
    'glGetTexEnviv','glGetTexEnvfv',
    'glGetTexGenfv','glGetTexGeniv','glGetTexGendv',
    'glGetTexLevelParameteriv',
    'glGetTexLevelParameterfv',
    'glGetTexParameterfv',
    'glGetTexParameteriv',
)

glGetString = platform.OpenGL.glGetString
glGetString.restype = ctypes.c_char_p
glGetString.__doc__ = """glGetString( constant ) -> Current string value"""

GL_GET_SIZES = {
    simple.GL_ACCUM_ALPHA_BITS                      : (1,),                
    simple.GL_ACCUM_BLUE_BITS                       : (1,),                
    simple.GL_ACCUM_CLEAR_VALUE                     : (4,),                
    simple.GL_ACCUM_GREEN_BITS                      : (1,),                
    simple.GL_ACCUM_RED_BITS                        : (1,),                
    simple.GL_ACTIVE_TEXTURE                        : (1,),
    simple.GL_ACTIVE_TEXTURE_ARB                    : (1,),                
    simple.GL_ALIASED_LINE_WIDTH_RANGE              : (2,),                
    simple.GL_ALIASED_POINT_SIZE_RANGE              : (2,),                
    simple.GL_ALPHA_BIAS                            : (1,),                
    simple.GL_ALPHA_BITS                            : (1,),                
    simple.GL_ALPHA_SCALE                           : (1,),                
    simple.GL_ALPHA_TEST                            : (1,),                
    simple.GL_ALPHA_TEST_FUNC                       : (1,),                
    simple.GL_ALPHA_TEST_REF                        : (1,),                
    simple.GL_ARRAY_BUFFER_BINDING                  : (1,),
    simple.GL_ATTRIB_STACK_DEPTH                    : (1,),                
    simple.GL_AUTO_NORMAL                           : (1,),                
    simple.GL_AUX_BUFFERS                           : (1,),                
    simple.GL_BLEND                                 : (1,),                
    simple.GL_BLEND_COLOR                           : (4,),                
    simple.GL_BLEND_DST_ALPHA                       : (1,),                
    simple.GL_BLEND_DST_RGB                         : (1,),                
    simple.GL_BLEND_EQUATION_RGB                    : (1,),                
    simple.GL_BLEND_EQUATION_ALPHA                  : (1,),                
    simple.GL_BLEND_SRC_RGB                         : (1,),                
    simple.GL_BLEND_SRC_ALPHA                       : (1,),                
    simple.GL_BLUE_BIAS                             : (1,),                
    simple.GL_BLUE_BITS                             : (1,),                
    simple.GL_BLUE_SCALE                            : (1,),                
    simple.GL_CLIENT_ACTIVE_TEXTURE                 : (1,),                
    simple.GL_CLIENT_ACTIVE_TEXTURE_ARB             : (1,),                
    simple.GL_CLIENT_ATTRIB_STACK_DEPTH             : (1,),                
    simple.GL_CLIP_PLANE0                           : (1,),                
    simple.GL_CLIP_PLANE1                           : (1,),                
    simple.GL_CLIP_PLANE2                           : (1,),                
    simple.GL_CLIP_PLANE3                           : (1,),                
    simple.GL_CLIP_PLANE4                           : (1,),                
    simple.GL_CLIP_PLANE5                           : (1,),                
    simple.GL_COLOR_ARRAY                           : (1,),                
    simple.GL_COLOR_ARRAY_BUFFER_BINDING            : (1,),                
    simple.GL_COLOR_ARRAY_SIZE                      : (1,),                
    simple.GL_COLOR_ARRAY_STRIDE                    : (1,),                
    simple.GL_COLOR_ARRAY_TYPE                      : (1,),                
    simple.GL_COLOR_CLEAR_VALUE                     : (4,),                
    simple.GL_COLOR_LOGIC_OP                        : (1,),                
    simple.GL_COLOR_MATERIAL                        : (1,),                
    simple.GL_COLOR_MATERIAL_FACE                   : (1,),                
    simple.GL_COLOR_MATERIAL_PARAMETER              : (1,),                
    simple.GL_COLOR_MATRIX                          : (4, 4),              
    simple.GL_COLOR_MATRIX_STACK_DEPTH              : (1,),                
    simple.GL_COLOR_SUM                             : (1,),                
    simple.GL_COLOR_TABLE                           : (1,),                
    simple.GL_COLOR_WRITEMASK                       : (4,),                
    # TODO: this *requires* a lookup to determine how many will be returned...
    #simple.GL_COMPRESSED_TEXTURE_FORMATS            : (4,),
    simple.GL_CONVOLUTION_1D                        : (1,),                
    simple.GL_CONVOLUTION_2D                        : (1,),                
    simple.GL_CULL_FACE                             : (1,),                
    simple.GL_CULL_FACE_MODE                        : (1,),                
    simple.GL_CURRENT_COLOR                         : (4,),                
    simple.GL_CURRENT_INDEX                         : (1,),                
    simple.GL_CURRENT_NORMAL                        : (3,),                
    simple.GL_CURRENT_RASTER_COLOR                  : (4,),                
    simple.GL_CURRENT_RASTER_DISTANCE               : (1,),                
    simple.GL_CURRENT_RASTER_INDEX                  : (1,),                
    simple.GL_CURRENT_RASTER_POSITION               : (4,),                
    simple.GL_CURRENT_RASTER_POSITION_VALID         : (1,),                
    simple.GL_CURRENT_RASTER_TEXTURE_COORDS         : (4,),                
    simple.GL_CURRENT_SECONDARY_COLOR               : (4,),                
    simple.GL_CURRENT_TEXTURE_COORDS                : (4,),                
    simple.GL_DEPTH_BIAS                            : (1,),                
    simple.GL_DEPTH_BITS                            : (1,),                
    simple.GL_DEPTH_CLEAR_VALUE                     : (1,),                
    simple.GL_DEPTH_FUNC                            : (1,),                
    simple.GL_DEPTH_RANGE                           : (2,),                
    simple.GL_DEPTH_SCALE                           : (1,),                
    simple.GL_DEPTH_TEST                            : (1,),                
    simple.GL_DEPTH_WRITEMASK                       : (1,),                
    simple.GL_DITHER                                : (1,),                
    simple.GL_DOUBLEBUFFER                          : (1,),                
    simple.GL_DRAW_BUFFER                           : (1,),                
    simple.GL_EDGE_FLAG                             : (1,),                
    simple.GL_EDGE_FLAG_ARRAY                       : (1,),                
    simple.GL_EDGE_FLAG_ARRAY_BUFFER_BINDING        : (1,),
    simple.GL_EDGE_FLAG_ARRAY_STRIDE                : (1,),
    simple.GL_ELEMENT_ARRAY_BUFFER_BINDING          : (1,),
    simple.GL_FEEDBACK_BUFFER_SIZE                  : (1,),                
    simple.GL_FEEDBACK_BUFFER_TYPE                  : (1,),                
    simple.GL_FOG                                   : (1,),                
    simple.GL_FOG_COORD_ARRAY                       : (1,),
    simple.GL_FOG_COORD_ARRAY_BUFFER_BINDING        : (1,),
    simple.GL_FOG_COORD_ARRAY_STRIDE                : (1,),
    simple.GL_FOG_COORD_ARRAY_TYPE                  : (1,),
    simple.GL_FOG_COORD_SRC                         : (1,),
    simple.GL_FOG_COLOR                             : (4,),                
    simple.GL_FOG_DENSITY                           : (1,),                
    simple.GL_FOG_END                               : (1,),                
    simple.GL_FOG_HINT                              : (1,),                
    simple.GL_FOG_INDEX                             : (1,),                
    simple.GL_FOG_MODE                              : (1,),                
    simple.GL_FOG_START                             : (1,),
    simple.GL_FRAGMENT_SHADER_DERIVATIVE_HINT       : (1,),
    simple.GL_FRONT_FACE                            : (1,),                
    simple.GL_GENERATE_MIPMAP_HINT                  : (1,),
    simple.GL_GREEN_BIAS                            : (1,),                
    simple.GL_GREEN_BITS                            : (1,),                
    simple.GL_GREEN_SCALE                           : (1,),                
    simple.GL_HISTOGRAM                             : (1,),                
    simple.GL_INDEX_ARRAY                           : (1,),  
    simple.GL_INDEX_ARRAY_BUFFER_BINDING            : (1,),
    simple.GL_INDEX_ARRAY_STRIDE                    : (1,),                
    simple.GL_INDEX_ARRAY_TYPE                      : (1,),                
    simple.GL_INDEX_BITS                            : (1,),                
    simple.GL_INDEX_CLEAR_VALUE                     : (1,),                
    simple.GL_INDEX_LOGIC_OP                        : (1,),                
    simple.GL_INDEX_MODE                            : (1,),                
    simple.GL_INDEX_OFFSET                          : (1,),                
    simple.GL_INDEX_SHIFT                           : (1,),                
    simple.GL_INDEX_WRITEMASK                       : (1,),                
    simple.GL_LIGHT0                                : (1,),                
    simple.GL_LIGHT1                                : (1,),                
    simple.GL_LIGHT2                                : (1,),                
    simple.GL_LIGHT3                                : (1,),                
    simple.GL_LIGHT4                                : (1,),                
    simple.GL_LIGHT5                                : (1,),                
    simple.GL_LIGHT6                                : (1,),                
    simple.GL_LIGHT7                                : (1,),                
    simple.GL_LIGHTING                              : (1,),                
    simple.GL_LIGHT_MODEL_AMBIENT                   : (4,),                
    simple.GL_LIGHT_MODEL_COLOR_CONTROL             : (1,),                
    simple.GL_LIGHT_MODEL_LOCAL_VIEWER              : (1,),                
    simple.GL_LIGHT_MODEL_TWO_SIDE                  : (1,),                
    simple.GL_LINE_SMOOTH                           : (1,),                
    simple.GL_LINE_SMOOTH_HINT                      : (1,),                
    simple.GL_LINE_STIPPLE                          : (1,),                
    simple.GL_LINE_STIPPLE_PATTERN                  : (1,),                
    simple.GL_LINE_STIPPLE_REPEAT                   : (1,),                
    simple.GL_LINE_WIDTH                            : (1,),                
    simple.GL_LINE_WIDTH_GRANULARITY                : (1,),                
    simple.GL_LINE_WIDTH_RANGE                      : (2,),                
    simple.GL_LIST_BASE                             : (1,),                
    simple.GL_LIST_INDEX                            : (1,),                
    simple.GL_LIST_MODE                             : (1,),                
    simple.GL_LOGIC_OP_MODE                         : (1,),                
    simple.GL_MAP1_COLOR_4                          : (1,),                
    simple.GL_MAP1_GRID_DOMAIN                      : (2,),                
    simple.GL_MAP1_GRID_SEGMENTS                    : (1,),                
    simple.GL_MAP1_INDEX                            : (1,),                
    simple.GL_MAP1_NORMAL                           : (1,),                
    simple.GL_MAP1_TEXTURE_COORD_1                  : (1,),                
    simple.GL_MAP1_TEXTURE_COORD_2                  : (1,),                
    simple.GL_MAP1_TEXTURE_COORD_3                  : (1,),                
    simple.GL_MAP1_TEXTURE_COORD_4                  : (1,),                
    simple.GL_MAP1_VERTEX_3                         : (1,),                
    simple.GL_MAP1_VERTEX_4                         : (1,),                
    simple.GL_MAP2_COLOR_4                          : (1,),                
    simple.GL_MAP2_GRID_DOMAIN                      : (4,),                
    simple.GL_MAP2_GRID_SEGMENTS                    : (2,),                
    simple.GL_MAP2_INDEX                            : (1,),                
    simple.GL_MAP2_NORMAL                           : (1,),                
    simple.GL_MAP2_TEXTURE_COORD_1                  : (1,),                
    simple.GL_MAP2_TEXTURE_COORD_2                  : (1,),                
    simple.GL_MAP2_TEXTURE_COORD_3                  : (1,),                
    simple.GL_MAP2_TEXTURE_COORD_4                  : (1,),                
    simple.GL_MAP2_VERTEX_3                         : (1,),                
    simple.GL_MAP2_VERTEX_4                         : (1,),                
    simple.GL_MAP_COLOR                             : (1,),                
    simple.GL_MAP_STENCIL                           : (1,),                
    simple.GL_MATRIX_MODE                           : (1,),                
    simple.GL_MAX_3D_TEXTURE_SIZE                   : (1,),                
    simple.GL_MAX_ATTRIB_STACK_DEPTH                : (1,),                
    simple.GL_MAX_CLIENT_ATTRIB_STACK_DEPTH         : (1,),                
    simple.GL_MAX_CLIP_PLANES                       : (1,),                
    simple.GL_MAX_COLOR_MATRIX_STACK_DEPTH          : (1,),                
    simple.GL_MAX_COMBINED_TEXTURE_IMAGE_UNITS      : (1,),
    simple.GL_MAX_CUBE_MAP_TEXTURE_SIZE             : (1,),
    simple.GL_MAX_DRAW_BUFFERS                      : (1,),
    simple.GL_MAX_ELEMENTS_INDICES                  : (1,),                
    simple.GL_MAX_ELEMENTS_VERTICES                 : (1,),                
    simple.GL_MAX_EVAL_ORDER                        : (1,),                
    simple.GL_MAX_LIGHTS                            : (1,),                
    simple.GL_MAX_LIST_NESTING                      : (1,),                
    simple.GL_MAX_MODELVIEW_STACK_DEPTH             : (1,),                
    simple.GL_MAX_NAME_STACK_DEPTH                  : (1,),                
    simple.GL_MAX_PIXEL_MAP_TABLE                   : (1,),                
    simple.GL_MAX_PROJECTION_STACK_DEPTH            : (1,),                
    simple.GL_MAX_TEXTURE_IMAGE_UNITS               : (1,),                
    simple.GL_MAX_TEXTURE_LOD_BIAS                  : (1,),
    simple.GL_MAX_TEXTURE_SIZE                      : (1,),                
    simple.GL_MAX_TEXTURE_STACK_DEPTH               : (1,),                
    simple.GL_MAX_TEXTURE_UNITS                     : (1,),                
    simple.GL_MAX_TEXTURE_UNITS_ARB                 : (1,),                
    simple.GL_MAX_VARYING_FLOATS                    : (1,),
    simple.GL_MAX_VERTEX_ATTRIBS                    : (1,),
    simple.GL_MAX_VERTEX_TEXTURE_IMAGE_UNITS        : (1,),
    simple.GL_MAX_VERTEX_UNIFORM_COMPONENTS         : (1,),
    simple.GL_MAX_VIEWPORT_DIMS                     : (2,),                
    simple.GL_MINMAX                                : (1,),                
    simple.GL_MODELVIEW_MATRIX                      : (4, 4),              
    simple.GL_MODELVIEW_STACK_DEPTH                 : (1,),                
    simple.GL_NAME_STACK_DEPTH                      : (1,),                
    simple.GL_NORMALIZE                             : (1,),                
    simple.GL_NORMAL_ARRAY                          : (1,),                
    simple.GL_NORMAL_ARRAY_BUFFER_BINDING           : (1,),
    simple.GL_NORMAL_ARRAY_STRIDE                   : (1,),                
    simple.GL_NORMAL_ARRAY_TYPE                     : (1,),
    simple.GL_NORMALIZE                             : (1,),
    simple.GL_NUM_COMPRESSED_TEXTURE_FORMATS        : (1,),
    simple.GL_PACK_ALIGNMENT                        : (1,),                
    simple.GL_PACK_IMAGE_HEIGHT                     : (1,),                
    simple.GL_PACK_LSB_FIRST                        : (1,),                
    simple.GL_PACK_ROW_LENGTH                       : (1,),                
    simple.GL_PACK_SKIP_IMAGES                      : (1,),                
    simple.GL_PACK_SKIP_PIXELS                      : (1,),                
    simple.GL_PACK_SKIP_ROWS                        : (1,),                
    simple.GL_PACK_SWAP_BYTES                       : (1,),                
    simple.GL_PERSPECTIVE_CORRECTION_HINT           : (1,),                
    simple.GL_PIXEL_MAP_A_TO_A_SIZE                 : (1,),                
    simple.GL_PIXEL_MAP_B_TO_B_SIZE                 : (1,),                
    simple.GL_PIXEL_MAP_G_TO_G_SIZE                 : (1,),                
    simple.GL_PIXEL_MAP_I_TO_A_SIZE                 : (1,),                
    simple.GL_PIXEL_MAP_I_TO_B_SIZE                 : (1,),                
    simple.GL_PIXEL_MAP_I_TO_G_SIZE                 : (1,),                
    simple.GL_PIXEL_MAP_I_TO_I_SIZE                 : (1,),                
    simple.GL_PIXEL_MAP_I_TO_R_SIZE                 : (1,),                
    simple.GL_PIXEL_MAP_R_TO_R_SIZE                 : (1,),                
    simple.GL_PIXEL_MAP_S_TO_S_SIZE                 : (1,),                
    simple.GL_PIXEL_PACK_BUFFER_BINDING_ARB         : (1,),
    simple.GL_PIXEL_UNPACK_BUFFER_BINDING_ARB       : (1,),
    simple.GL_POINT_DISTANCE_ATTENUATION            : (3,),
    simple.GL_POINT_FADE_THRESHOLD_SIZE             : (1,),
    simple.GL_POINT_SIZE                            : (1,),                
    simple.GL_POINT_SIZE_GRANULARITY                : (1,),                
    simple.GL_POINT_SIZE_MAX                        : (1,),
    simple.GL_POINT_SIZE_MIN                        : (1,),
    simple.GL_POINT_SIZE_RANGE                      : (2,),                
    simple.GL_POINT_SMOOTH                          : (1,),                
    simple.GL_POINT_SMOOTH_HINT                     : (1,),                
    simple.GL_POLYGON_MODE                          : (2,),                
    simple.GL_POLYGON_OFFSET_FACTOR                 : (1,),                
    simple.GL_POLYGON_OFFSET_FILL                   : (1,),                
    simple.GL_POLYGON_OFFSET_LINE                   : (1,),                
    simple.GL_POLYGON_OFFSET_POINT                  : (1,),                
    simple.GL_POLYGON_OFFSET_UNITS                  : (1,),                
    simple.GL_POLYGON_SMOOTH                        : (1,),                
    simple.GL_POLYGON_SMOOTH_HINT                   : (1,),                
    simple.GL_POLYGON_STIPPLE                       : (1,),
    simple.GL_POST_COLOR_MATRIX_ALPHA_BIAS          : (1,),                
    simple.GL_POST_COLOR_MATRIX_ALPHA_SCALE         : (1,),                
    simple.GL_POST_COLOR_MATRIX_BLUE_BIAS           : (1,),                
    simple.GL_POST_COLOR_MATRIX_BLUE_SCALE          : (1,),                
    simple.GL_POST_COLOR_MATRIX_COLOR_TABLE         : (1,),                
    simple.GL_POST_COLOR_MATRIX_GREEN_BIAS          : (1,),                
    simple.GL_POST_COLOR_MATRIX_GREEN_SCALE         : (1,),                
    simple.GL_POST_COLOR_MATRIX_RED_BIAS            : (1,),                
    simple.GL_POST_COLOR_MATRIX_RED_SCALE           : (1,),                
    simple.GL_POST_CONVOLUTION_ALPHA_BIAS           : (1,),                
    simple.GL_POST_CONVOLUTION_ALPHA_SCALE          : (1,),                
    simple.GL_POST_CONVOLUTION_BLUE_BIAS            : (1,),                
    simple.GL_POST_CONVOLUTION_BLUE_SCALE           : (1,),                
    simple.GL_POST_CONVOLUTION_COLOR_TABLE          : (1,),                
    simple.GL_POST_CONVOLUTION_GREEN_BIAS           : (1,),                
    simple.GL_POST_CONVOLUTION_GREEN_SCALE          : (1,),                
    simple.GL_POST_CONVOLUTION_RED_BIAS             : (1,),                
    simple.GL_POST_CONVOLUTION_RED_SCALE            : (1,),                
    simple.GL_PROJECTION_MATRIX                     : (4, 4),              
    simple.GL_PROJECTION_STACK_DEPTH                : (1,),                
    simple.GL_READ_BUFFER                           : (1,),                
    simple.GL_RED_BIAS                              : (1,),                
    simple.GL_RED_BITS                              : (1,),                
    simple.GL_RED_SCALE                             : (1,),                
    simple.GL_RENDER_MODE                           : (1,),                
    simple.GL_RESCALE_NORMAL                        : (1,),                
    simple.GL_RGBA_MODE                             : (1,),                
    simple.GL_SAMPLE_BUFFERS                        : (1,),
    simple.GL_SAMPLE_COVERAGE_VALUE                 : (1,),
    simple.GL_SAMPLE_COVERAGE_INVERT                : (1,),
    simple.GL_SAMPLES                               : (1,),
    simple.GL_SCISSOR_BOX                           : (4,),                
    simple.GL_SCISSOR_TEST                          : (1,),                
    simple.GL_SECONDARY_COLOR_ARRAY                 : (1,),
    simple.GL_SECONDARY_COLOR_ARRAY_BUFFER_BINDING  : (1,),
    simple.GL_SECONDARY_COLOR_ARRAY_SIZE            : (1,),
    simple.GL_SECONDARY_COLOR_ARRAY_STRIDE          : (1,),
    simple.GL_SECONDARY_COLOR_ARRAY_TYPE            : (1,),
    simple.GL_SELECTION_BUFFER_SIZE                 : (1,),                
    simple.GL_SEPARABLE_2D                          : (1,),                
    simple.GL_SHADE_MODEL                           : (1,),
    simple.GL_SMOOTH_LINE_WIDTH_RANGE               : (1,),
    simple.GL_SMOOTH_LINE_WIDTH_GRANULARITY         : (1,),
    simple.GL_SMOOTH_POINT_SIZE_RANGE               : (2,),
    simple.GL_SMOOTH_POINT_SIZE_GRANULARITY         : (1,),
    simple.GL_STENCIL_BACK_FAIL                     : (1,),
    simple.GL_STENCIL_BACK_FUNC                     : (1,),
    simple.GL_STENCIL_BACK_PASS_DEPTH_FAIL          : (1,),
    simple.GL_STENCIL_BACK_PASS_DEPTH_PASS          : (1,),
    simple.GL_STENCIL_BACK_REF                      : (1,),
    simple.GL_STENCIL_BACK_VALUE_MASK               : (1,),
    simple.GL_STENCIL_BACK_WRITEMASK                : (1,),
    simple.GL_STENCIL_BITS                          : (1,),                
    simple.GL_STENCIL_CLEAR_VALUE                   : (1,),                
    simple.GL_STENCIL_FAIL                          : (1,),                
    simple.GL_STENCIL_FUNC                          : (1,),                
    simple.GL_STENCIL_PASS_DEPTH_FAIL               : (1,),                
    simple.GL_STENCIL_PASS_DEPTH_PASS               : (1,),                
    simple.GL_STENCIL_REF                           : (1,),                
    simple.GL_STENCIL_TEST                          : (1,),                
    simple.GL_STENCIL_VALUE_MASK                    : (1,),                
    simple.GL_STENCIL_WRITEMASK                     : (1,),                
    simple.GL_STEREO                                : (1,),                
    simple.GL_SUBPIXEL_BITS                         : (1,),
    simple.GL_TEXTURE_1D                            : (1,),
    simple.GL_TEXTURE_2D                            : (1,),
    simple.GL_TEXTURE_3D                            : (1,),
    simple.GL_TEXTURE_CUBE_MAP                      : (1,),
    simple.GL_TEXTURE_BINDING_1D                    : (1,),
    simple.GL_TEXTURE_BINDING_2D                    : (1,),
    simple.GL_TEXTURE_BINDING_3D                    : (1,),
    simple.GL_TEXTURE_BINDING_CUBE_MAP              : (1,),
    simple.GL_TEXTURE_COMPRESSION_HINT              : (1,),
    simple.GL_TEXTURE_COORD_ARRAY                   : (1,),
    simple.GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING    : (1,),
    simple.GL_TEXTURE_COORD_ARRAY_SIZE              : (1,),
    simple.GL_TEXTURE_COORD_ARRAY_STRIDE            : (1,),
    simple.GL_TEXTURE_COORD_ARRAY_TYPE              : (1,),
    simple.GL_TEXTURE_GEN_Q                         : (1,),
    simple.GL_TEXTURE_GEN_R                         : (1,),
    simple.GL_TEXTURE_GEN_S                         : (1,),
    simple.GL_TEXTURE_GEN_T                         : (1,),
    simple.GL_TEXTURE_MATRIX                        : (4, 4),
    simple.GL_TEXTURE_STACK_DEPTH                   : (1,),
    simple.GL_TRANSPOSE_COLOR_MATRIX                : (4,4),
    simple.GL_TRANSPOSE_MODELVIEW_MATRIX            : (4,4),
    simple.GL_TRANSPOSE_PROJECTION_MATRIX           : (4,4),
    simple.GL_TRANSPOSE_TEXTURE_MATRIX              : (4,4),
    simple.GL_UNPACK_ALIGNMENT                      : (1,),
    simple.GL_UNPACK_IMAGE_HEIGHT                   : (1,),
    simple.GL_UNPACK_LSB_FIRST                      : (1,),
    simple.GL_UNPACK_ROW_LENGTH                     : (1,),
    simple.GL_UNPACK_SKIP_IMAGES                    : (1,),
    simple.GL_UNPACK_SKIP_PIXELS                    : (1,),
    simple.GL_UNPACK_SKIP_ROWS                      : (1,),
    simple.GL_UNPACK_SWAP_BYTES                     : (1,),
    simple.GL_VERTEX_ARRAY                          : (1,),
    simple.GL_VERTEX_ARRAY_BUFFER_BINDING           : (1,),
    simple.GL_VERTEX_ARRAY_SIZE                     : (1,),
    simple.GL_VERTEX_ARRAY_STRIDE                   : (1,),
    simple.GL_VERTEX_ARRAY_TYPE                     : (1,),
    simple.GL_VERTEX_PROGRAM_POINT_SIZE             : (1,),
    simple.GL_VERTEX_PROGRAM_TWO_SIDE               : (1,),
    simple.GL_VIEWPORT                              : (4,),
    simple.GL_ZOOM_X                                : (1,),
    simple.GL_ZOOM_Y                                : (1,),
    
    # Constants beyond OpenGL 2.1 (see src/find_glget_constants.py)...
    # Note: there are more, this is just what *my* hardware can find...
    simple.GL_ARRAY_ELEMENT_LOCK_COUNT_EXT: (1,),
    simple.GL_ARRAY_ELEMENT_LOCK_FIRST_EXT: (1,),
    simple.GL_BLEND_DST: (1,),
    simple.GL_BLEND_SRC: (1,),
    simple.GL_CLAMP_FRAGMENT_COLOR_ARB: (1,),
    simple.GL_CLAMP_READ_COLOR_ARB: (1,),
    simple.GL_CLAMP_VERTEX_COLOR_ARB: (1,),
    simple.GL_COLOR_ALPHA_PAIRING_ATI: (1,),
    simple.GL_COLOR_ARRAY_COUNT_EXT: (1,),
    simple.GL_COMPRESSED_TEXTURE_FORMATS: (1,),
    simple.GL_COMPRESSED_TEXTURE_FORMATS_ARB: (1,),
    simple.GL_CURRENT_FOG_COORDINATE: (1,),
    simple.GL_CURRENT_FOG_COORDINATE: (1,),
    simple.GL_CURRENT_FOG_COORDINATE_EXT: (1,),
    simple.GL_CURRENT_MATRIX_ARB: (4, 4),
    simple.GL_CURRENT_MATRIX_NV: (4, 4),
    simple.GL_CURRENT_MATRIX_STACK_DEPTH_ARB: (1,),
    simple.GL_CURRENT_MATRIX_STACK_DEPTH_NV: (1,),
    simple.GL_CURRENT_PROGRAM: (1,),
    simple.GL_DRAW_BUFFER0: (1,),
    simple.GL_DRAW_BUFFER0_ARB: (1,),
    simple.GL_DRAW_BUFFER0_ATI: (1,),
    simple.GL_DRAW_BUFFER1: (1,),
    simple.GL_DRAW_BUFFER10: (1,),
    simple.GL_DRAW_BUFFER10_ARB: (1,),
    simple.GL_DRAW_BUFFER10_ATI: (1,),
    simple.GL_DRAW_BUFFER11: (1,),
    simple.GL_DRAW_BUFFER11_ARB: (1,),
    simple.GL_DRAW_BUFFER11_ATI: (1,),
    simple.GL_DRAW_BUFFER12: (1,),
    simple.GL_DRAW_BUFFER12_ARB: (1,),
    simple.GL_DRAW_BUFFER12_ATI: (1,),
    simple.GL_DRAW_BUFFER13: (1,),
    simple.GL_DRAW_BUFFER13_ARB: (1,),
    simple.GL_DRAW_BUFFER13_ATI: (1,),
    simple.GL_DRAW_BUFFER14: (1,),
    simple.GL_DRAW_BUFFER14_ARB: (1,),
    simple.GL_DRAW_BUFFER14_ATI: (1,),
    simple.GL_DRAW_BUFFER15: (1,),
    simple.GL_DRAW_BUFFER15_ARB: (1,),
    simple.GL_DRAW_BUFFER15_ATI: (1,),
    simple.GL_DRAW_BUFFER1_ARB: (1,),
    simple.GL_DRAW_BUFFER1_ATI: (1,),
    simple.GL_DRAW_BUFFER2: (1,),
    simple.GL_DRAW_BUFFER2_ARB: (1,),
    simple.GL_DRAW_BUFFER2_ATI: (1,),
    simple.GL_DRAW_BUFFER3: (1,),
    simple.GL_DRAW_BUFFER3_ARB: (1,),
    simple.GL_DRAW_BUFFER3_ATI: (1,),
    simple.GL_DRAW_BUFFER4: (1,),
    simple.GL_DRAW_BUFFER4_ARB: (1,),
    simple.GL_DRAW_BUFFER4_ATI: (1,),
    simple.GL_DRAW_BUFFER5: (1,),
    simple.GL_DRAW_BUFFER5_ARB: (1,),
    simple.GL_DRAW_BUFFER5_ATI: (1,),
    simple.GL_DRAW_BUFFER6: (1,),
    simple.GL_DRAW_BUFFER6_ARB: (1,),
    simple.GL_DRAW_BUFFER6_ATI: (1,),
    simple.GL_DRAW_BUFFER7: (1,),
    simple.GL_DRAW_BUFFER7_ARB: (1,),
    simple.GL_DRAW_BUFFER7_ATI: (1,),
    simple.GL_DRAW_BUFFER8: (1,),
    simple.GL_DRAW_BUFFER8_ARB: (1,),
    simple.GL_DRAW_BUFFER8_ATI: (1,),
    simple.GL_DRAW_BUFFER9: (1,),
    simple.GL_DRAW_BUFFER9_ARB: (1,),
    simple.GL_DRAW_BUFFER9_ATI: (1,),
    simple.GL_EDGE_FLAG_ARRAY_COUNT_EXT: (1,),
    simple.GL_FRAGMENT_PROGRAM_ARB: (1,),
    simple.GL_FRAGMENT_SHADER_ATI: (1,),
    simple.GL_FRAMEBUFFER_BINDING_EXT: (1,),
    simple.GL_INDEX_ARRAY_COUNT_EXT: (1,),
    simple.GL_MAX_COLOR_ATTACHMENTS_EXT: (1,),
    simple.GL_MAX_FRAGMENT_UNIFORM_COMPONENTS: (1,),
    simple.GL_MAX_FRAGMENT_UNIFORM_COMPONENTS_ARB: (1,),
    simple.GL_MAX_PROGRAM_MATRICES_ARB: (1,),
    simple.GL_MAX_PROGRAM_MATRIX_STACK_DEPTH_ARB: (1,),
    simple.GL_MAX_RECTANGLE_TEXTURE_SIZE_ARB: (1,),
    simple.GL_MAX_RECTANGLE_TEXTURE_SIZE_NV: (1,),
    simple.GL_MAX_RENDERBUFFER_SIZE_EXT: (1,),
    simple.GL_MAX_TEXTURE_COORDS: (1,),
    simple.GL_MAX_TEXTURE_COORDS_ARB: (1,),
    simple.GL_MAX_TEXTURE_COORDS_NV: (1,),
    simple.GL_MAX_TEXTURE_MAX_ANISOTROPY_EXT: (1,),
    simple.GL_MAX_TRACK_MATRICES_NV: (1,),
    simple.GL_MAX_TRACK_MATRIX_STACK_DEPTH_NV: (1,),
    simple.GL_MULTISAMPLE: (1,),
    simple.GL_MULTISAMPLE_ARB: (1,),
    simple.GL_MULTISAMPLE_EXT: (1,),
    simple.GL_MULTISAMPLE_SGIS: (1,),
    simple.GL_NORMAL_ARRAY_COUNT_EXT: (1,),
    simple.GL_NUM_FRAGMENT_CONSTANTS_ATI: (1,),
    simple.GL_NUM_FRAGMENT_REGISTERS_ATI: (1,),
    simple.GL_NUM_INPUT_INTERPOLATOR_COMPONENTS_ATI: (1,),
    simple.GL_NUM_INSTRUCTIONS_PER_PASS_ATI: (1,),
    simple.GL_NUM_INSTRUCTIONS_TOTAL_ATI: (1,),
    simple.GL_NUM_LOOPBACK_COMPONENTS_ATI: (1,),
    simple.GL_NUM_PASSES_ATI: (1,),
    simple.GL_PIXEL_COUNTER_BITS_NV: (1,),
    simple.GL_POINT_SPRITE: (1,),
    simple.GL_POINT_SPRITE_ARB: (1,),
    simple.GL_POINT_SPRITE_COORD_ORIGIN: (1,),
    simple.GL_POINT_SPRITE_NV: (1,),
    simple.GL_PRIMITIVE_RESTART_INDEX_NV: (1,),
    simple.GL_PRIMITIVE_RESTART_NV: (1,),
    simple.GL_PROGRAM_ERROR_POSITION_ARB: (1,),
    simple.GL_PROGRAM_ERROR_POSITION_NV: (1,),
    simple.GL_QUERY_COUNTER_BITS: (1,),
    simple.GL_QUERY_COUNTER_BITS_ARB: (1,),
    simple.GL_RENDERBUFFER_BINDING_EXT: (1,),
    simple.GL_RGBA_FLOAT_MODE_ARB: (1,),
    simple.GL_SAMPLE_ALPHA_TO_COVERAGE: (1,),
    simple.GL_SAMPLE_ALPHA_TO_COVERAGE_ARB: (1,),
    simple.GL_SAMPLE_ALPHA_TO_MASK_EXT: (1,),
    simple.GL_SAMPLE_ALPHA_TO_MASK_SGIS: (1,),
    simple.GL_SAMPLE_ALPHA_TO_ONE: (1,),
    simple.GL_SAMPLE_ALPHA_TO_ONE_ARB: (1,),
    simple.GL_SAMPLE_ALPHA_TO_ONE_EXT: (1,),
    simple.GL_SAMPLE_ALPHA_TO_ONE_SGIS: (1,),
    simple.GL_SAMPLE_COVERAGE: (1,),
    simple.GL_SAMPLE_COVERAGE_ARB: (1,),
    simple.GL_SAMPLE_MASK_EXT: (1,),
    simple.GL_SAMPLE_MASK_SGIS: (1,),
    simple.GL_TEXTURE_BINDING_RECTANGLE_ARB: (1,),
    simple.GL_TEXTURE_BINDING_RECTANGLE_NV: (1,),
    simple.GL_TEXTURE_COORD_ARRAY_COUNT_EXT: (1,),
    simple.GL_TEXTURE_RECTANGLE_ARB: (1,),
    simple.GL_TEXTURE_RECTANGLE_NV: (1,),
    simple.GL_TRANSPOSE_CURRENT_MATRIX_ARB: (4, 4),
    simple.GL_TYPE_RGBA_FLOAT_ATI: (1,),
    simple.GL_UNPACK_CLIENT_STORAGE_APPLE: (1,),
    simple.GL_VERTEX_ARRAY_BINDING_APPLE: (1,),
    simple.GL_VERTEX_ARRAY_COUNT_EXT: (1,),
    simple.GL_VERTEX_PROGRAM_ARB: (1,),
    simple.GL_VERTEX_PROGRAM_NV: (1,),
    simple.GL_VERTEX_SHADER_EXT: (1,),
}
def addGLGetConstant( constant, arraySize ):
    """Add a glGet* constant to return an output array of correct size"""
    GL_GET_SIZES[ constant ] = arraySize
glGetDouble = glGetDoublev = wrapper.wrapper(simple.glGetDoublev).setOutput(
    "params",GL_GET_SIZES, "pname", 
)
glGetFloat = glGetFloatv = wrapper.wrapper(simple.glGetFloatv).setOutput(
    "params",GL_GET_SIZES, "pname", 
)
glGetBoolean = glGetBooleanv = glGetInteger = glGetIntegerv = wrapper.wrapper(simple.glGetIntegerv).setOutput(
    "params",GL_GET_SIZES, "pname", 
)

GL_GET_LIGHT_SIZES = {
    # glGetLightXv
    simple.GL_AMBIENT                               : (4,),
    simple.GL_DIFFUSE                               : (4,),
    simple.GL_SPECULAR                              : (4,),
    simple.GL_POSITION                              : (4,),
    simple.GL_SPOT_DIRECTION                        : (3,),
    simple.GL_SPOT_EXPONENT                         : (1,),
    simple.GL_SPOT_CUTOFF                           : (1,),
    simple.GL_CONSTANT_ATTENUATION                  : (1,),
    simple.GL_LINEAR_ATTENUATION                    : (1,),
    simple.GL_QUADRATIC_ATTENUATION                 : (1,),
} # end of sizes
glGetLightfv = wrapper.wrapper(simple.glGetLightfv).setOutput(
    "params",GL_GET_LIGHT_SIZES, "pname", 
)
glGetLightiv = wrapper.wrapper(simple.glGetLightiv).setOutput(
    "params",GL_GET_LIGHT_SIZES, "pname", 
)

GL_GET_MATERIAL_SIZES = {
    simple.GL_AMBIENT: (4,),
    simple.GL_DIFFUSE: (4,),
    simple.GL_SPECULAR: (4,),
    simple.GL_EMISSION: (4,),
    simple.GL_SHININESS: (1,),
    simple.GL_COLOR_INDEXES: (3,)
}
glGetMaterialfv = wrapper.wrapper(simple.glGetMaterialfv).setOutput(
    "params",GL_GET_MATERIAL_SIZES, "pname", 
)
glGetMaterialiv = wrapper.wrapper(simple.glGetMaterialiv).setOutput(
    "params",GL_GET_MATERIAL_SIZES, "pname", 
)
PIXEL_MAP_SIZE_CONSTANT_MAP = {
    simple.GL_PIXEL_MAP_A_TO_A: simple.GL_PIXEL_MAP_A_TO_A_SIZE,
    simple.GL_PIXEL_MAP_B_TO_B: simple.GL_PIXEL_MAP_B_TO_B_SIZE,
    simple.GL_PIXEL_MAP_G_TO_G: simple.GL_PIXEL_MAP_G_TO_G_SIZE,
    simple.GL_PIXEL_MAP_I_TO_A: simple.GL_PIXEL_MAP_I_TO_A_SIZE,
    simple.GL_PIXEL_MAP_I_TO_B: simple.GL_PIXEL_MAP_I_TO_B_SIZE,
    simple.GL_PIXEL_MAP_I_TO_G: simple.GL_PIXEL_MAP_I_TO_G_SIZE,
    simple.GL_PIXEL_MAP_I_TO_I: simple.GL_PIXEL_MAP_I_TO_I_SIZE,
    simple.GL_PIXEL_MAP_I_TO_R: simple.GL_PIXEL_MAP_I_TO_R_SIZE,
    simple.GL_PIXEL_MAP_R_TO_R: simple.GL_PIXEL_MAP_R_TO_R_SIZE,
    simple.GL_PIXEL_MAP_S_TO_S: simple.GL_PIXEL_MAP_S_TO_S_SIZE,
}
def GL_GET_PIXEL_MAP_SIZE( pname ):
    """Given a pname, lookup the size using a glGet query..."""
    constant = PIXEL_MAP_SIZE_CONSTANT_MAP[ pname ]
    return glGetIntegerv( constant )
glGetPixelMapfv = wrapper.wrapper(simple.glGetPixelMapfv).setOutput(
    "values",GL_GET_PIXEL_MAP_SIZE, "map", 
)
glGetPixelMapuiv = wrapper.wrapper(simple.glGetPixelMapuiv).setOutput(
    "values",GL_GET_PIXEL_MAP_SIZE, "map", 
)
glGetPixelMapusv = wrapper.wrapper(simple.glGetPixelMapusv).setOutput(
    "values",GL_GET_PIXEL_MAP_SIZE, "map", 
)

# 32 * 32 bits
POLYGON_STIPPLE_SIZE = (32*32//8,)
glGetPolygonStipple = glGetPolygonStippleub = wrapper.wrapper(simple.glGetPolygonStipple).setOutput(
    "mask",POLYGON_STIPPLE_SIZE, 
)
GL_GET_TEX_ENV_SIZES = {
    simple.GL_TEXTURE_ENV_MODE: (1,),
    simple.GL_TEXTURE_ENV_COLOR: (4,),
}
glGetTexEnvfv = wrapper.wrapper(simple.glGetTexEnvfv).setOutput(
    "params",GL_GET_TEX_ENV_SIZES, 'pname',  
)
glGetTexEnviv = wrapper.wrapper(simple.glGetTexEnviv).setOutput(
    "params",GL_GET_TEX_ENV_SIZES, 'pname',  
)
GL_GET_TEX_GEN_SIZES = {
    simple.GL_TEXTURE_GEN_MODE: (1,),
    simple.GL_OBJECT_PLANE: (4,),
    simple.GL_EYE_PLANE: (4,),
}
glGetTexGendv = wrapper.wrapper(simple.glGetTexGendv).setOutput(
    "params",GL_GET_TEX_GEN_SIZES, 'pname',  
)
glGetTexGenfv = wrapper.wrapper(simple.glGetTexGenfv).setOutput(
    "params",GL_GET_TEX_GEN_SIZES, 'pname',  
)
glGetTexGeniv = wrapper.wrapper(simple.glGetTexGeniv).setOutput(
    "params",GL_GET_TEX_GEN_SIZES, 'pname',  
)

glGetTexLevelParameterfv = wrapper.wrapper(simple.glGetTexLevelParameterfv).setOutput(
    "params",(1,)
)
glGetTexLevelParameteriv = wrapper.wrapper(simple.glGetTexLevelParameteriv).setOutput(
    "params",(1,)
)
TEX_PARAMETER_SIZES = {
    simple.GL_TEXTURE_MAG_FILTER: (1,),
    simple.GL_TEXTURE_MIN_FILTER: (1,), 
    simple.GL_TEXTURE_MIN_LOD: (1,),
    simple.GL_TEXTURE_MAX_LOD: (1,),
    simple.GL_TEXTURE_BASE_LEVEL: (1,),
    simple.GL_TEXTURE_MAX_LEVEL: (1,),
    simple.GL_TEXTURE_WRAP_S: (1,),
    simple.GL_TEXTURE_WRAP_T: (1,),
    simple.GL_TEXTURE_WRAP_R: (1,),
    simple.GL_TEXTURE_BORDER_COLOR: (4,), 
    simple.GL_TEXTURE_PRIORITY: (1,),
    simple.GL_TEXTURE_RESIDENT: (1,)
}

glGetTexParameterfv = wrapper.wrapper(simple.glGetTexParameterfv).setOutput(
    "params",TEX_PARAMETER_SIZES, 'pname',
)
glGetTexParameteriv = wrapper.wrapper(simple.glGetTexParameteriv).setOutput(
    "params",TEX_PARAMETER_SIZES, 'pname',
)



'''OpenGL extension EXT.texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_texture'
_DEPRECATED = False
GL_ALPHA4_EXT = constant.Constant( 'GL_ALPHA4_EXT', 0x803B )
GL_ALPHA8_EXT = constant.Constant( 'GL_ALPHA8_EXT', 0x803C )
GL_ALPHA12_EXT = constant.Constant( 'GL_ALPHA12_EXT', 0x803D )
GL_ALPHA16_EXT = constant.Constant( 'GL_ALPHA16_EXT', 0x803E )
GL_LUMINANCE4_EXT = constant.Constant( 'GL_LUMINANCE4_EXT', 0x803F )
GL_LUMINANCE8_EXT = constant.Constant( 'GL_LUMINANCE8_EXT', 0x8040 )
GL_LUMINANCE12_EXT = constant.Constant( 'GL_LUMINANCE12_EXT', 0x8041 )
GL_LUMINANCE16_EXT = constant.Constant( 'GL_LUMINANCE16_EXT', 0x8042 )
GL_LUMINANCE4_ALPHA4_EXT = constant.Constant( 'GL_LUMINANCE4_ALPHA4_EXT', 0x8043 )
GL_LUMINANCE6_ALPHA2_EXT = constant.Constant( 'GL_LUMINANCE6_ALPHA2_EXT', 0x8044 )
GL_LUMINANCE8_ALPHA8_EXT = constant.Constant( 'GL_LUMINANCE8_ALPHA8_EXT', 0x8045 )
GL_LUMINANCE12_ALPHA4_EXT = constant.Constant( 'GL_LUMINANCE12_ALPHA4_EXT', 0x8046 )
GL_LUMINANCE12_ALPHA12_EXT = constant.Constant( 'GL_LUMINANCE12_ALPHA12_EXT', 0x8047 )
GL_LUMINANCE16_ALPHA16_EXT = constant.Constant( 'GL_LUMINANCE16_ALPHA16_EXT', 0x8048 )
GL_INTENSITY_EXT = constant.Constant( 'GL_INTENSITY_EXT', 0x8049 )
GL_INTENSITY4_EXT = constant.Constant( 'GL_INTENSITY4_EXT', 0x804A )
GL_INTENSITY8_EXT = constant.Constant( 'GL_INTENSITY8_EXT', 0x804B )
GL_INTENSITY12_EXT = constant.Constant( 'GL_INTENSITY12_EXT', 0x804C )
GL_INTENSITY16_EXT = constant.Constant( 'GL_INTENSITY16_EXT', 0x804D )
GL_RGB2_EXT = constant.Constant( 'GL_RGB2_EXT', 0x804E )
GL_RGB4_EXT = constant.Constant( 'GL_RGB4_EXT', 0x804F )
GL_RGB5_EXT = constant.Constant( 'GL_RGB5_EXT', 0x8050 )
GL_RGB8_EXT = constant.Constant( 'GL_RGB8_EXT', 0x8051 )
GL_RGB10_EXT = constant.Constant( 'GL_RGB10_EXT', 0x8052 )
GL_RGB12_EXT = constant.Constant( 'GL_RGB12_EXT', 0x8053 )
GL_RGB16_EXT = constant.Constant( 'GL_RGB16_EXT', 0x8054 )
GL_RGBA2_EXT = constant.Constant( 'GL_RGBA2_EXT', 0x8055 )
GL_RGBA4_EXT = constant.Constant( 'GL_RGBA4_EXT', 0x8056 )
GL_RGB5_A1_EXT = constant.Constant( 'GL_RGB5_A1_EXT', 0x8057 )
GL_RGBA8_EXT = constant.Constant( 'GL_RGBA8_EXT', 0x8058 )
GL_RGB10_A2_EXT = constant.Constant( 'GL_RGB10_A2_EXT', 0x8059 )
GL_RGBA12_EXT = constant.Constant( 'GL_RGBA12_EXT', 0x805A )
GL_RGBA16_EXT = constant.Constant( 'GL_RGBA16_EXT', 0x805B )
GL_TEXTURE_RED_SIZE_EXT = constant.Constant( 'GL_TEXTURE_RED_SIZE_EXT', 0x805C )
GL_TEXTURE_GREEN_SIZE_EXT = constant.Constant( 'GL_TEXTURE_GREEN_SIZE_EXT', 0x805D )
GL_TEXTURE_BLUE_SIZE_EXT = constant.Constant( 'GL_TEXTURE_BLUE_SIZE_EXT', 0x805E )
GL_TEXTURE_ALPHA_SIZE_EXT = constant.Constant( 'GL_TEXTURE_ALPHA_SIZE_EXT', 0x805F )
GL_TEXTURE_LUMINANCE_SIZE_EXT = constant.Constant( 'GL_TEXTURE_LUMINANCE_SIZE_EXT', 0x8060 )
GL_TEXTURE_INTENSITY_SIZE_EXT = constant.Constant( 'GL_TEXTURE_INTENSITY_SIZE_EXT', 0x8061 )
GL_REPLACE_EXT = constant.Constant( 'GL_REPLACE_EXT', 0x8062 )
GL_PROXY_TEXTURE_1D_EXT = constant.Constant( 'GL_PROXY_TEXTURE_1D_EXT', 0x8063 )
GL_PROXY_TEXTURE_2D_EXT = constant.Constant( 'GL_PROXY_TEXTURE_2D_EXT', 0x8064 )
GL_TEXTURE_TOO_LARGE_EXT = constant.Constant( 'GL_TEXTURE_TOO_LARGE_EXT', 0x8065 )


def glInitTextureEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ATI.map_object_buffer

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_map_object_buffer'
_DEPRECATED = False

glMapObjectBufferATI = platform.createExtensionFunction( 
'glMapObjectBufferATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=ctypes.c_void_p, 
argTypes=(constants.GLuint,),
doc='glMapObjectBufferATI(GLuint(buffer)) -> ctypes.c_void_p',
argNames=('buffer',),
deprecated=_DEPRECATED,
)

glUnmapObjectBufferATI = platform.createExtensionFunction( 
'glUnmapObjectBufferATI',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glUnmapObjectBufferATI(GLuint(buffer)) -> None',
argNames=('buffer',),
deprecated=_DEPRECATED,
)


def glInitMapObjectBufferATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.texture_float

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_float'
_DEPRECATED = False
GL_TEXTURE_RED_TYPE_ARB = constant.Constant( 'GL_TEXTURE_RED_TYPE_ARB', 0x8C10 )
GL_TEXTURE_GREEN_TYPE_ARB = constant.Constant( 'GL_TEXTURE_GREEN_TYPE_ARB', 0x8C11 )
GL_TEXTURE_BLUE_TYPE_ARB = constant.Constant( 'GL_TEXTURE_BLUE_TYPE_ARB', 0x8C12 )
GL_TEXTURE_ALPHA_TYPE_ARB = constant.Constant( 'GL_TEXTURE_ALPHA_TYPE_ARB', 0x8C13 )
GL_TEXTURE_LUMINANCE_TYPE_ARB = constant.Constant( 'GL_TEXTURE_LUMINANCE_TYPE_ARB', 0x8C14 )
GL_TEXTURE_INTENSITY_TYPE_ARB = constant.Constant( 'GL_TEXTURE_INTENSITY_TYPE_ARB', 0x8C15 )
GL_TEXTURE_DEPTH_TYPE_ARB = constant.Constant( 'GL_TEXTURE_DEPTH_TYPE_ARB', 0x8C16 )
GL_UNSIGNED_NORMALIZED_ARB = constant.Constant( 'GL_UNSIGNED_NORMALIZED_ARB', 0x8C17 )
GL_RGBA32F_ARB = constant.Constant( 'GL_RGBA32F_ARB', 0x8814 )
GL_RGB32F_ARB = constant.Constant( 'GL_RGB32F_ARB', 0x8815 )
GL_ALPHA32F_ARB = constant.Constant( 'GL_ALPHA32F_ARB', 0x8816 )
GL_INTENSITY32F_ARB = constant.Constant( 'GL_INTENSITY32F_ARB', 0x8817 )
GL_LUMINANCE32F_ARB = constant.Constant( 'GL_LUMINANCE32F_ARB', 0x8818 )
GL_LUMINANCE_ALPHA32F_ARB = constant.Constant( 'GL_LUMINANCE_ALPHA32F_ARB', 0x8819 )
GL_RGBA16F_ARB = constant.Constant( 'GL_RGBA16F_ARB', 0x881A )
GL_RGB16F_ARB = constant.Constant( 'GL_RGB16F_ARB', 0x881B )
GL_ALPHA16F_ARB = constant.Constant( 'GL_ALPHA16F_ARB', 0x881C )
GL_INTENSITY16F_ARB = constant.Constant( 'GL_INTENSITY16F_ARB', 0x881D )
GL_LUMINANCE16F_ARB = constant.Constant( 'GL_LUMINANCE16F_ARB', 0x881E )
GL_LUMINANCE_ALPHA16F_ARB = constant.Constant( 'GL_LUMINANCE_ALPHA16F_ARB', 0x881F )


def glInitTextureFloatARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_3_0

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_3_0'
_DEPRECATED = False
GL_COMPARE_REF_TO_TEXTURE = constant.Constant( 'GL_COMPARE_REF_TO_TEXTURE', 0x884E )
GL_CLIP_DISTANCE0 = constant.Constant( 'GL_CLIP_DISTANCE0', 0x3000 )
GL_CLIP_DISTANCE1 = constant.Constant( 'GL_CLIP_DISTANCE1', 0x3001 )
GL_CLIP_DISTANCE2 = constant.Constant( 'GL_CLIP_DISTANCE2', 0x3002 )
GL_CLIP_DISTANCE3 = constant.Constant( 'GL_CLIP_DISTANCE3', 0x3003 )
GL_CLIP_DISTANCE4 = constant.Constant( 'GL_CLIP_DISTANCE4', 0x3004 )
GL_CLIP_DISTANCE5 = constant.Constant( 'GL_CLIP_DISTANCE5', 0x3005 )
GL_CLIP_DISTANCE6 = constant.Constant( 'GL_CLIP_DISTANCE6', 0x3006 )
GL_CLIP_DISTANCE7 = constant.Constant( 'GL_CLIP_DISTANCE7', 0x3007 )
GL_MAX_CLIP_DISTANCES = constant.Constant( 'GL_MAX_CLIP_DISTANCES', 0xD32 )
GL_MAJOR_VERSION = constant.Constant( 'GL_MAJOR_VERSION', 0x821B )
GL_MINOR_VERSION = constant.Constant( 'GL_MINOR_VERSION', 0x821C )
GL_NUM_EXTENSIONS = constant.Constant( 'GL_NUM_EXTENSIONS', 0x821D )
GL_CONTEXT_FLAGS = constant.Constant( 'GL_CONTEXT_FLAGS', 0x821E )
GL_DEPTH_BUFFER = constant.Constant( 'GL_DEPTH_BUFFER', 0x8223 )
GL_STENCIL_BUFFER = constant.Constant( 'GL_STENCIL_BUFFER', 0x8224 )
GL_COMPRESSED_RED = constant.Constant( 'GL_COMPRESSED_RED', 0x8225 )
GL_COMPRESSED_RG = constant.Constant( 'GL_COMPRESSED_RG', 0x8226 )
GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT = constant.Constant( 'GL_CONTEXT_FLAG_FORWARD_COMPATIBLE_BIT', 0x1 )
GL_RGBA32F = constant.Constant( 'GL_RGBA32F', 0x8814 )
GL_RGB32F = constant.Constant( 'GL_RGB32F', 0x8815 )
GL_RGBA16F = constant.Constant( 'GL_RGBA16F', 0x881A )
GL_RGB16F = constant.Constant( 'GL_RGB16F', 0x881B )
GL_VERTEX_ATTRIB_ARRAY_INTEGER = constant.Constant( 'GL_VERTEX_ATTRIB_ARRAY_INTEGER', 0x88FD )
GL_MAX_ARRAY_TEXTURE_LAYERS = constant.Constant( 'GL_MAX_ARRAY_TEXTURE_LAYERS', 0x88FF )
GL_MIN_PROGRAM_TEXEL_OFFSET = constant.Constant( 'GL_MIN_PROGRAM_TEXEL_OFFSET', 0x8904 )
GL_MAX_PROGRAM_TEXEL_OFFSET = constant.Constant( 'GL_MAX_PROGRAM_TEXEL_OFFSET', 0x8905 )
GL_CLAMP_READ_COLOR = constant.Constant( 'GL_CLAMP_READ_COLOR', 0x891C )
GL_FIXED_ONLY = constant.Constant( 'GL_FIXED_ONLY', 0x891D )
GL_MAX_VARYING_COMPONENTS = constant.Constant( 'GL_MAX_VARYING_COMPONENTS', 0x8B4B )
GL_TEXTURE_1D_ARRAY = constant.Constant( 'GL_TEXTURE_1D_ARRAY', 0x8C18 )
GL_PROXY_TEXTURE_1D_ARRAY = constant.Constant( 'GL_PROXY_TEXTURE_1D_ARRAY', 0x8C19 )
GL_TEXTURE_2D_ARRAY = constant.Constant( 'GL_TEXTURE_2D_ARRAY', 0x8C1A )
GL_PROXY_TEXTURE_2D_ARRAY = constant.Constant( 'GL_PROXY_TEXTURE_2D_ARRAY', 0x8C1B )
GL_TEXTURE_BINDING_1D_ARRAY = constant.Constant( 'GL_TEXTURE_BINDING_1D_ARRAY', 0x8C1C )
GL_TEXTURE_BINDING_2D_ARRAY = constant.Constant( 'GL_TEXTURE_BINDING_2D_ARRAY', 0x8C1D )
GL_R11F_G11F_B10F = constant.Constant( 'GL_R11F_G11F_B10F', 0x8C3A )
GL_UNSIGNED_INT_10F_11F_11F_REV = constant.Constant( 'GL_UNSIGNED_INT_10F_11F_11F_REV', 0x8C3B )
GL_RGB9_E5 = constant.Constant( 'GL_RGB9_E5', 0x8C3D )
GL_UNSIGNED_INT_5_9_9_9_REV = constant.Constant( 'GL_UNSIGNED_INT_5_9_9_9_REV', 0x8C3E )
GL_TEXTURE_SHARED_SIZE = constant.Constant( 'GL_TEXTURE_SHARED_SIZE', 0x8C3F )
GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH = constant.Constant( 'GL_TRANSFORM_FEEDBACK_VARYING_MAX_LENGTH', 0x8C76 )
GL_TRANSFORM_FEEDBACK_BUFFER_MODE = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_MODE', 0x8C7F )
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS = constant.Constant( 'GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_COMPONENTS', 0x8C80 )
GL_TRANSFORM_FEEDBACK_VARYINGS = constant.Constant( 'GL_TRANSFORM_FEEDBACK_VARYINGS', 0x8C83 )
GL_TRANSFORM_FEEDBACK_BUFFER_START = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_START', 0x8C84 )
GL_TRANSFORM_FEEDBACK_BUFFER_SIZE = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_SIZE', 0x8C85 )
GL_PRIMITIVES_GENERATED = constant.Constant( 'GL_PRIMITIVES_GENERATED', 0x8C87 )
GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN = constant.Constant( 'GL_TRANSFORM_FEEDBACK_PRIMITIVES_WRITTEN', 0x8C88 )
GL_RASTERIZER_DISCARD = constant.Constant( 'GL_RASTERIZER_DISCARD', 0x8C89 )
GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS = constant.Constant( 'GL_MAX_TRANSFORM_FEEDBACK_INTERLEAVED_COMPONENTS', 0x8C8A )
GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS = constant.Constant( 'GL_MAX_TRANSFORM_FEEDBACK_SEPARATE_ATTRIBS', 0x8C8B )
GL_INTERLEAVED_ATTRIBS = constant.Constant( 'GL_INTERLEAVED_ATTRIBS', 0x8C8C )
GL_SEPARATE_ATTRIBS = constant.Constant( 'GL_SEPARATE_ATTRIBS', 0x8C8D )
GL_TRANSFORM_FEEDBACK_BUFFER = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER', 0x8C8E )
GL_TRANSFORM_FEEDBACK_BUFFER_BINDING = constant.Constant( 'GL_TRANSFORM_FEEDBACK_BUFFER_BINDING', 0x8C8F )
GL_RGBA32UI = constant.Constant( 'GL_RGBA32UI', 0x8D70 )
GL_RGB32UI = constant.Constant( 'GL_RGB32UI', 0x8D71 )
GL_RGBA16UI = constant.Constant( 'GL_RGBA16UI', 0x8D76 )
GL_RGB16UI = constant.Constant( 'GL_RGB16UI', 0x8D77 )
GL_RGBA8UI = constant.Constant( 'GL_RGBA8UI', 0x8D7C )
GL_RGB8UI = constant.Constant( 'GL_RGB8UI', 0x8D7D )
GL_RGBA32I = constant.Constant( 'GL_RGBA32I', 0x8D82 )
GL_RGB32I = constant.Constant( 'GL_RGB32I', 0x8D83 )
GL_RGBA16I = constant.Constant( 'GL_RGBA16I', 0x8D88 )
GL_RGB16I = constant.Constant( 'GL_RGB16I', 0x8D89 )
GL_RGBA8I = constant.Constant( 'GL_RGBA8I', 0x8D8E )
GL_RGB8I = constant.Constant( 'GL_RGB8I', 0x8D8F )
GL_RED_INTEGER = constant.Constant( 'GL_RED_INTEGER', 0x8D94 )
GL_GREEN_INTEGER = constant.Constant( 'GL_GREEN_INTEGER', 0x8D95 )
GL_BLUE_INTEGER = constant.Constant( 'GL_BLUE_INTEGER', 0x8D96 )
GL_RGB_INTEGER = constant.Constant( 'GL_RGB_INTEGER', 0x8D98 )
GL_RGBA_INTEGER = constant.Constant( 'GL_RGBA_INTEGER', 0x8D99 )
GL_BGR_INTEGER = constant.Constant( 'GL_BGR_INTEGER', 0x8D9A )
GL_BGRA_INTEGER = constant.Constant( 'GL_BGRA_INTEGER', 0x8D9B )
GL_SAMPLER_1D_ARRAY = constant.Constant( 'GL_SAMPLER_1D_ARRAY', 0x8DC0 )
GL_SAMPLER_2D_ARRAY = constant.Constant( 'GL_SAMPLER_2D_ARRAY', 0x8DC1 )
GL_SAMPLER_1D_ARRAY_SHADOW = constant.Constant( 'GL_SAMPLER_1D_ARRAY_SHADOW', 0x8DC3 )
GL_SAMPLER_2D_ARRAY_SHADOW = constant.Constant( 'GL_SAMPLER_2D_ARRAY_SHADOW', 0x8DC4 )
GL_SAMPLER_CUBE_SHADOW = constant.Constant( 'GL_SAMPLER_CUBE_SHADOW', 0x8DC5 )
GL_UNSIGNED_INT_VEC2 = constant.Constant( 'GL_UNSIGNED_INT_VEC2', 0x8DC6 )
GL_UNSIGNED_INT_VEC3 = constant.Constant( 'GL_UNSIGNED_INT_VEC3', 0x8DC7 )
GL_UNSIGNED_INT_VEC4 = constant.Constant( 'GL_UNSIGNED_INT_VEC4', 0x8DC8 )
GL_INT_SAMPLER_1D = constant.Constant( 'GL_INT_SAMPLER_1D', 0x8DC9 )
GL_INT_SAMPLER_2D = constant.Constant( 'GL_INT_SAMPLER_2D', 0x8DCA )
GL_INT_SAMPLER_3D = constant.Constant( 'GL_INT_SAMPLER_3D', 0x8DCB )
GL_INT_SAMPLER_CUBE = constant.Constant( 'GL_INT_SAMPLER_CUBE', 0x8DCC )
GL_INT_SAMPLER_1D_ARRAY = constant.Constant( 'GL_INT_SAMPLER_1D_ARRAY', 0x8DCE )
GL_INT_SAMPLER_2D_ARRAY = constant.Constant( 'GL_INT_SAMPLER_2D_ARRAY', 0x8DCF )
GL_UNSIGNED_INT_SAMPLER_1D = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_1D', 0x8DD1 )
GL_UNSIGNED_INT_SAMPLER_2D = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_2D', 0x8DD2 )
GL_UNSIGNED_INT_SAMPLER_3D = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_3D', 0x8DD3 )
GL_UNSIGNED_INT_SAMPLER_CUBE = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_CUBE', 0x8DD4 )
GL_UNSIGNED_INT_SAMPLER_1D_ARRAY = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_1D_ARRAY', 0x8DD6 )
GL_UNSIGNED_INT_SAMPLER_2D_ARRAY = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_2D_ARRAY', 0x8DD7 )
GL_QUERY_WAIT = constant.Constant( 'GL_QUERY_WAIT', 0x8E13 )
GL_QUERY_NO_WAIT = constant.Constant( 'GL_QUERY_NO_WAIT', 0x8E14 )
GL_QUERY_BY_REGION_WAIT = constant.Constant( 'GL_QUERY_BY_REGION_WAIT', 0x8E15 )
GL_QUERY_BY_REGION_NO_WAIT = constant.Constant( 'GL_QUERY_BY_REGION_NO_WAIT', 0x8E16 )
GL_BUFFER_ACCESS_FLAGS = constant.Constant( 'GL_BUFFER_ACCESS_FLAGS', 0x911F )
GL_BUFFER_MAP_LENGTH = constant.Constant( 'GL_BUFFER_MAP_LENGTH', 0x9120 )
GL_BUFFER_MAP_OFFSET = constant.Constant( 'GL_BUFFER_MAP_OFFSET', 0x9121 )
glColorMaski = platform.createExtensionFunction( 
'glColorMaski',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLboolean,constants.GLboolean,constants.GLboolean,constants.GLboolean,),
doc='glColorMaski(GLuint(index), GLboolean(r), GLboolean(g), GLboolean(b), GLboolean(a)) -> None',
argNames=('index','r','g','b','a',),
deprecated=_DEPRECATED,
)

glGetBooleani_v = platform.createExtensionFunction( 
'glGetBooleani_v',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLbooleanArray,),
doc='glGetBooleani_v(GLenum(target), GLuint(index), GLbooleanArray(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glGetIntegeri_v = platform.createExtensionFunction( 
'glGetIntegeri_v',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glGetIntegeri_v(GLenum(target), GLuint(index), GLintArray(data)) -> None',
argNames=('target','index','data',),
deprecated=_DEPRECATED,
)

glEnablei = platform.createExtensionFunction( 
'glEnablei',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glEnablei(GLenum(target), GLuint(index)) -> None',
argNames=('target','index',),
deprecated=_DEPRECATED,
)

glDisablei = platform.createExtensionFunction( 
'glDisablei',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glDisablei(GLenum(target), GLuint(index)) -> None',
argNames=('target','index',),
deprecated=_DEPRECATED,
)

glIsEnabledi = platform.createExtensionFunction( 
'glIsEnabledi',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glIsEnabledi(GLenum(target), GLuint(index)) -> constants.GLboolean',
argNames=('target','index',),
deprecated=_DEPRECATED,
)

glBeginTransformFeedback = platform.createExtensionFunction( 
'glBeginTransformFeedback',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glBeginTransformFeedback(GLenum(primitiveMode)) -> None',
argNames=('primitiveMode',),
deprecated=_DEPRECATED,
)

glEndTransformFeedback = platform.createExtensionFunction( 
'glEndTransformFeedback',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glEndTransformFeedback() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glBindBufferRange = platform.createExtensionFunction( 
'glBindBufferRange',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLintptr,constants.GLsizeiptr,),
doc='glBindBufferRange(GLenum(target), GLuint(index), GLuint(buffer), GLintptr(offset), GLsizeiptr(size)) -> None',
argNames=('target','index','buffer','offset','size',),
deprecated=_DEPRECATED,
)

glBindBufferBase = platform.createExtensionFunction( 
'glBindBufferBase',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,),
doc='glBindBufferBase(GLenum(target), GLuint(index), GLuint(buffer)) -> None',
argNames=('target','index','buffer',),
deprecated=_DEPRECATED,
)

glTransformFeedbackVaryings = platform.createExtensionFunction( 
'glTransformFeedbackVaryings',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,ctypes.POINTER( ctypes.POINTER( constants.GLchar )),constants.GLenum,),
doc='glTransformFeedbackVaryings(GLuint(program), GLsizei(count), POINTER( ctypes.POINTER( constants.GLchar ))(varyings), GLenum(bufferMode)) -> None',
argNames=('program','count','varyings','bufferMode',),
deprecated=_DEPRECATED,
)

glGetTransformFeedbackVarying = platform.createExtensionFunction( 
'glGetTransformFeedbackVarying',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLsizei,arrays.GLsizeiArray,arrays.GLsizeiArray,arrays.GLuintArray,arrays.GLcharArray,),
doc='glGetTransformFeedbackVarying(GLuint(program), GLuint(index), GLsizei(bufSize), GLsizeiArray(length), GLsizeiArray(size), GLuintArray(type), GLcharArray(name)) -> None',
argNames=('program','index','bufSize','length','size','type','name',),
deprecated=_DEPRECATED,
)

glClampColor = platform.createExtensionFunction( 
'glClampColor',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glClampColor(GLenum(target), GLenum(clamp)) -> None',
argNames=('target','clamp',),
deprecated=_DEPRECATED,
)

glBeginConditionalRender = platform.createExtensionFunction( 
'glBeginConditionalRender',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glBeginConditionalRender(GLuint(id), GLenum(mode)) -> None',
argNames=('id','mode',),
deprecated=_DEPRECATED,
)

glEndConditionalRender = platform.createExtensionFunction( 
'glEndConditionalRender',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glEndConditionalRender() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glVertexAttribIPointer = platform.createExtensionFunction( 
'glVertexAttribIPointer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glVertexAttribIPointer(GLuint(index), GLint(size), GLenum(type), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('index','size','type','stride','pointer',),
deprecated=_DEPRECATED,
)

glGetVertexAttribIiv = platform.createExtensionFunction( 
'glGetVertexAttribIiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetVertexAttribIiv(GLuint(index), GLenum(pname), GLintArray(params)) -> None',
argNames=('index','pname','params',),
deprecated=_DEPRECATED,
)

glGetVertexAttribIuiv = platform.createExtensionFunction( 
'glGetVertexAttribIuiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLuintArray,),
doc='glGetVertexAttribIuiv(GLuint(index), GLenum(pname), GLuintArray(params)) -> None',
argNames=('index','pname','params',),
deprecated=_DEPRECATED,
)

glVertexAttribI1i = platform.createExtensionFunction( 
'glVertexAttribI1i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,),
doc='glVertexAttribI1i(GLuint(index), GLint(x)) -> None',
argNames=('index','x',),
deprecated=_DEPRECATED,
)

glVertexAttribI2i = platform.createExtensionFunction( 
'glVertexAttribI2i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,),
doc='glVertexAttribI2i(GLuint(index), GLint(x), GLint(y)) -> None',
argNames=('index','x','y',),
deprecated=_DEPRECATED,
)

glVertexAttribI3i = platform.createExtensionFunction( 
'glVertexAttribI3i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,constants.GLint,),
doc='glVertexAttribI3i(GLuint(index), GLint(x), GLint(y), GLint(z)) -> None',
argNames=('index','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexAttribI4i = platform.createExtensionFunction( 
'glVertexAttribI4i',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glVertexAttribI4i(GLuint(index), GLint(x), GLint(y), GLint(z), GLint(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttribI1ui = platform.createExtensionFunction( 
'glVertexAttribI1ui',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,),
doc='glVertexAttribI1ui(GLuint(index), GLuint(x)) -> None',
argNames=('index','x',),
deprecated=_DEPRECATED,
)

glVertexAttribI2ui = platform.createExtensionFunction( 
'glVertexAttribI2ui',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glVertexAttribI2ui(GLuint(index), GLuint(x), GLuint(y)) -> None',
argNames=('index','x','y',),
deprecated=_DEPRECATED,
)

glVertexAttribI3ui = platform.createExtensionFunction( 
'glVertexAttribI3ui',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glVertexAttribI3ui(GLuint(index), GLuint(x), GLuint(y), GLuint(z)) -> None',
argNames=('index','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexAttribI4ui = platform.createExtensionFunction( 
'glVertexAttribI4ui',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glVertexAttribI4ui(GLuint(index), GLuint(x), GLuint(y), GLuint(z), GLuint(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttribI1iv = platform.createExtensionFunction( 
'glVertexAttribI1iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLintArray,),
doc='glVertexAttribI1iv(GLuint(index), GLintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI2iv = platform.createExtensionFunction( 
'glVertexAttribI2iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLintArray,),
doc='glVertexAttribI2iv(GLuint(index), GLintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI3iv = platform.createExtensionFunction( 
'glVertexAttribI3iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLintArray,),
doc='glVertexAttribI3iv(GLuint(index), GLintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI4iv = platform.createExtensionFunction( 
'glVertexAttribI4iv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLintArray,),
doc='glVertexAttribI4iv(GLuint(index), GLintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI1uiv = platform.createExtensionFunction( 
'glVertexAttribI1uiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLuintArray,),
doc='glVertexAttribI1uiv(GLuint(index), GLuintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI2uiv = platform.createExtensionFunction( 
'glVertexAttribI2uiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLuintArray,),
doc='glVertexAttribI2uiv(GLuint(index), GLuintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI3uiv = platform.createExtensionFunction( 
'glVertexAttribI3uiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLuintArray,),
doc='glVertexAttribI3uiv(GLuint(index), GLuintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI4uiv = platform.createExtensionFunction( 
'glVertexAttribI4uiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLuintArray,),
doc='glVertexAttribI4uiv(GLuint(index), GLuintArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI4bv = platform.createExtensionFunction( 
'glVertexAttribI4bv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLbyteArray,),
doc='glVertexAttribI4bv(GLuint(index), GLbyteArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI4sv = platform.createExtensionFunction( 
'glVertexAttribI4sv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVertexAttribI4sv(GLuint(index), GLshortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI4ubv = platform.createExtensionFunction( 
'glVertexAttribI4ubv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLubyteArray,),
doc='glVertexAttribI4ubv(GLuint(index), GLubyteArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribI4usv = platform.createExtensionFunction( 
'glVertexAttribI4usv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLushortArray,),
doc='glVertexAttribI4usv(GLuint(index), GLushortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glGetUniformuiv = platform.createExtensionFunction( 
'glGetUniformuiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLint,arrays.GLuintArray,),
doc='glGetUniformuiv(GLuint(program), GLint(location), GLuintArray(params)) -> None',
argNames=('program','location','params',),
deprecated=_DEPRECATED,
)

glBindFragDataLocation = platform.createExtensionFunction( 
'glBindFragDataLocation',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,arrays.GLcharArray,),
doc='glBindFragDataLocation(GLuint(program), GLuint(color), GLcharArray(name)) -> None',
argNames=('program','color','name',),
deprecated=_DEPRECATED,
)

glGetFragDataLocation = platform.createExtensionFunction( 
'glGetFragDataLocation',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLint, 
argTypes=(constants.GLuint,arrays.GLcharArray,),
doc='glGetFragDataLocation(GLuint(program), GLcharArray(name)) -> constants.GLint',
argNames=('program','name',),
deprecated=_DEPRECATED,
)

glUniform1ui = platform.createExtensionFunction( 
'glUniform1ui',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLuint,),
doc='glUniform1ui(GLint(location), GLuint(v0)) -> None',
argNames=('location','v0',),
deprecated=_DEPRECATED,
)

glUniform2ui = platform.createExtensionFunction( 
'glUniform2ui',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLuint,constants.GLuint,),
doc='glUniform2ui(GLint(location), GLuint(v0), GLuint(v1)) -> None',
argNames=('location','v0','v1',),
deprecated=_DEPRECATED,
)

glUniform3ui = platform.createExtensionFunction( 
'glUniform3ui',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glUniform3ui(GLint(location), GLuint(v0), GLuint(v1), GLuint(v2)) -> None',
argNames=('location','v0','v1','v2',),
deprecated=_DEPRECATED,
)

glUniform4ui = platform.createExtensionFunction( 
'glUniform4ui',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glUniform4ui(GLint(location), GLuint(v0), GLuint(v1), GLuint(v2), GLuint(v3)) -> None',
argNames=('location','v0','v1','v2','v3',),
deprecated=_DEPRECATED,
)

glUniform1uiv = platform.createExtensionFunction( 
'glUniform1uiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glUniform1uiv(GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform2uiv = platform.createExtensionFunction( 
'glUniform2uiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glUniform2uiv(GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform3uiv = platform.createExtensionFunction( 
'glUniform3uiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glUniform3uiv(GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glUniform4uiv = platform.createExtensionFunction( 
'glUniform4uiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLsizei,arrays.GLuintArray,),
doc='glUniform4uiv(GLint(location), GLsizei(count), GLuintArray(value)) -> None',
argNames=('location','count','value',),
deprecated=_DEPRECATED,
)

glTexParameterIiv = platform.createExtensionFunction( 
'glTexParameterIiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glTexParameterIiv(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glTexParameterIuiv = platform.createExtensionFunction( 
'glTexParameterIuiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glTexParameterIuiv(GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTexParameterIiv = platform.createExtensionFunction( 
'glGetTexParameterIiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetTexParameterIiv(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetTexParameterIuiv = platform.createExtensionFunction( 
'glGetTexParameterIuiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLuintArray,),
doc='glGetTexParameterIuiv(GLenum(target), GLenum(pname), GLuintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glClearBufferiv = platform.createExtensionFunction( 
'glClearBufferiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,arrays.GLintArray,),
doc='glClearBufferiv(GLenum(buffer), GLint(drawbuffer), GLintArray(value)) -> None',
argNames=('buffer','drawbuffer','value',),
deprecated=_DEPRECATED,
)

glClearBufferuiv = platform.createExtensionFunction( 
'glClearBufferuiv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,arrays.GLuintArray,),
doc='glClearBufferuiv(GLenum(buffer), GLint(drawbuffer), GLuintArray(value)) -> None',
argNames=('buffer','drawbuffer','value',),
deprecated=_DEPRECATED,
)

glClearBufferfv = platform.createExtensionFunction( 
'glClearBufferfv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,arrays.GLfloatArray,),
doc='glClearBufferfv(GLenum(buffer), GLint(drawbuffer), GLfloatArray(value)) -> None',
argNames=('buffer','drawbuffer','value',),
deprecated=_DEPRECATED,
)

glClearBufferfi = platform.createExtensionFunction( 
'glClearBufferfi',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLfloat,constants.GLint,),
doc='glClearBufferfi(GLenum(buffer), GLint(drawbuffer), GLfloat(depth), GLint(stencil)) -> None',
argNames=('buffer','drawbuffer','depth','stencil',),
deprecated=_DEPRECATED,
)

glGetStringi = platform.createExtensionFunction( 
'glGetStringi',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=arrays.GLubyteArray, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glGetStringi(GLenum(name), GLuint(index)) -> arrays.GLubyteArray',
argNames=('name','index',),
deprecated=_DEPRECATED,
)
# import legacy entry points to allow checking for bool(entryPoint)
from OpenGL.raw.GL.VERSION.GL_3_0_DEPRECATED import *



'''OpenGL extension OML.subsample

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_OML_subsample'
_DEPRECATED = False
GL_FORMAT_SUBSAMPLE_24_24_OML = constant.Constant( 'GL_FORMAT_SUBSAMPLE_24_24_OML', 0x8982 )
GL_FORMAT_SUBSAMPLE_244_244_OML = constant.Constant( 'GL_FORMAT_SUBSAMPLE_244_244_OML', 0x8983 )


def glInitSubsampleOML():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
